#
# PySNMP MIB module MPLS-TC-STD-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/MPLS-TC-STD-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:13:51 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ValueSizeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ValueSizeConstraint", "ConstraintsIntersection")
( ModuleCompliance, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "NotificationGroup")
( Bits, Unsigned32, Integer32, Counter32, Gauge32, iso, MibIdentifier, ModuleIdentity, TimeTicks, ObjectIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, NotificationType, transmission, IpAddress, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "Bits", "Unsigned32", "Integer32", "Counter32", "Gauge32", "iso", "MibIdentifier", "ModuleIdentity", "TimeTicks", "ObjectIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "NotificationType", "transmission", "IpAddress", "Counter64")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
mplsTCStdMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 10, 166, 1)).setRevisions(("2004-06-03 00:00",))
if mibBuilder.loadTexts: mplsTCStdMIB.setLastUpdated('200406030000Z')
if mibBuilder.loadTexts: mplsTCStdMIB.setOrganization('IETF Multiprotocol Label Switching (MPLS) Working\n              Group.')
if mibBuilder.loadTexts: mplsTCStdMIB.setContactInfo('        Thomas D. Nadeau\n                        Cisco Systems, Inc.\n                        tnadeau@cisco.com\n\n                        Joan Cucchiara\n                        Marconi Communications, Inc.\n                        jcucchiara@mindspring.com\n\n                        Cheenu Srinivasan\n                        Bloomberg L.P.\n                        cheenu@bloomberg.net\n\n                        Arun Viswanathan\n                        Force10 Networks, Inc.\n                        arunv@force10networks.com\n\n                        Hans Sjostrand\n                        ipUnplugged\n                        hans@ipunplugged.com\n\n                        Kireeti Kompella\n                        Juniper Networks\n                        kireeti@juniper.net\n\n             Email comments to the MPLS WG Mailing List at\n             mpls@uu.net.')
if mibBuilder.loadTexts: mplsTCStdMIB.setDescription('Copyright (C) The Internet Society (2004). The\n              initial version of this MIB module was published\n              in RFC 3811. For full legal notices see the RFC\n              itself or see:\n              http://www.ietf.org/copyrights/ianamib.html\n\n              This MIB module defines TEXTUAL-CONVENTIONs\n              for concepts used in Multiprotocol Label\n              Switching (MPLS) networks.')
mplsStdMIB = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 166))
class MplsAtmVcIdentifier(Integer32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Integer32.subtypeSpec+ValueRangeConstraint(32,65535)

class MplsBitRate(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,4294967295),)
class MplsBurstSize(Unsigned32, TextualConvention):
    displayHint = 'd'
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,4294967295)

class MplsExtendedTunnelId(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,4294967295)

class MplsLabel(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,4294967295)

class MplsLabelDistributionMethod(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("downstreamOnDemand", 1), ("downstreamUnsolicited", 2),)

class MplsLdpIdentifier(OctetString, TextualConvention):
    displayHint = '1d.1d.1d.1d:2d'
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(6,6)
    fixedLength = 6

class MplsLsrIdentifier(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

class MplsLdpLabelType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3,))
    namedValues = NamedValues(("generic", 1), ("atm", 2), ("frameRelay", 3),)

class MplsLSPID(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ConstraintsUnion(ValueSizeConstraint(2,2),ValueSizeConstraint(6,6),)
class MplsLspType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4,))
    namedValues = NamedValues(("unknown", 1), ("terminatingLsp", 2), ("originatingLsp", 3), ("crossConnectingLsp", 4),)

class MplsOwner(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7,))
    namedValues = NamedValues(("unknown", 1), ("other", 2), ("snmp", 3), ("ldp", 4), ("crldp", 5), ("rsvpTe", 6), ("policyAgent", 7),)

class MplsPathIndexOrZero(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,4294967295)

class MplsPathIndex(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(1,4294967295)

class MplsRetentionMode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2,))
    namedValues = NamedValues(("conservative", 1), ("liberal", 2),)

class MplsTunnelAffinity(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,4294967295)

class MplsTunnelIndex(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ValueRangeConstraint(0,65535)

class MplsTunnelInstanceIndex(Unsigned32, TextualConvention):
    subtypeSpec = Unsigned32.subtypeSpec+ConstraintsUnion(ValueRangeConstraint(0,0),ValueRangeConstraint(1,65535),ValueRangeConstraint(65536,4294967295),)
class TeHopAddressType(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(0, 1, 2, 3, 4, 5,))
    namedValues = NamedValues(("unknown", 0), ("ipv4", 1), ("ipv6", 2), ("asnumber", 3), ("unnum", 4), ("lspid", 5),)

class TeHopAddress(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(0,32)

class TeHopAddressAS(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

class TeHopAddressUnnum(OctetString, TextualConvention):
    subtypeSpec = OctetString.subtypeSpec+ValueSizeConstraint(4,4)
    fixedLength = 4

mibBuilder.exportSymbols("MPLS-TC-STD-MIB", MplsLspType=MplsLspType, MplsTunnelIndex=MplsTunnelIndex, MplsTunnelInstanceIndex=MplsTunnelInstanceIndex, TeHopAddressUnnum=TeHopAddressUnnum, mplsTCStdMIB=mplsTCStdMIB, MplsLdpLabelType=MplsLdpLabelType, MplsLdpIdentifier=MplsLdpIdentifier, MplsLabel=MplsLabel, MplsRetentionMode=MplsRetentionMode, TeHopAddressAS=TeHopAddressAS, TeHopAddressType=TeHopAddressType, MplsExtendedTunnelId=MplsExtendedTunnelId, mplsStdMIB=mplsStdMIB, MplsOwner=MplsOwner, MplsLabelDistributionMethod=MplsLabelDistributionMethod, MplsBitRate=MplsBitRate, MplsTunnelAffinity=MplsTunnelAffinity, MplsPathIndexOrZero=MplsPathIndexOrZero, MplsBurstSize=MplsBurstSize, PYSNMP_MODULE_ID=mplsTCStdMIB, MplsPathIndex=MplsPathIndex, MplsLsrIdentifier=MplsLsrIdentifier, MplsAtmVcIdentifier=MplsAtmVcIdentifier, TeHopAddress=TeHopAddress, MplsLSPID=MplsLSPID)



#
# PySNMP MIB module SCTP-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/SCTP-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:27:46 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( OctetString, Integer, ObjectIdentifier, ) = mibBuilder.importSymbols("ASN1", "OctetString", "Integer", "ObjectIdentifier")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( SingleValueConstraint, ConstraintsIntersection, ValueSizeConstraint, ConstraintsUnion, ValueRangeConstraint, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "SingleValueConstraint", "ConstraintsIntersection", "ValueSizeConstraint", "ConstraintsUnion", "ValueRangeConstraint")
( InetPortNumber, InetAddress, InetAddressType, ) = mibBuilder.importSymbols("INET-ADDRESS-MIB", "InetPortNumber", "InetAddress", "InetAddressType")
( NotificationGroup, ModuleCompliance, ObjectGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance", "ObjectGroup")
( iso, TimeTicks, MibScalar, MibTable, MibTableRow, MibTableColumn, mib_2, NotificationType, IpAddress, ObjectIdentity, Gauge32, Unsigned32, MibIdentifier, Counter32, ModuleIdentity, Integer32, Bits, Counter64, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "TimeTicks", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "mib-2", "NotificationType", "IpAddress", "ObjectIdentity", "Gauge32", "Unsigned32", "MibIdentifier", "Counter32", "ModuleIdentity", "Integer32", "Bits", "Counter64")
( TimeStamp, TextualConvention, TruthValue, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TimeStamp", "TextualConvention", "TruthValue", "DisplayString")
sctpMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 104)).setRevisions(("2004-09-02 00:00",))
if mibBuilder.loadTexts: sctpMIB.setLastUpdated('200409020000Z')
if mibBuilder.loadTexts: sctpMIB.setOrganization('IETF SIGTRAN Working Group')
if mibBuilder.loadTexts: sctpMIB.setContactInfo('\n        WG EMail: sigtran@ietf.org\n\n        Web Page:\n              http://www.ietf.org/html.charters/sigtran-charter.html\n\n        Chair:     Lyndon Ong\n                   Ciena Corporation\n                   0480 Ridgeview Drive\n                   Cupertino, CA  95014\n                   USA\n                   Tel:\n                   Email: lyong@ciena.com\n\n        Editors:   Maria-Carmen Belinchon\n                   R&D Department\n                   Ericsson Espana S. A.\n                   Via de los Poblados, 13\n                   28033 Madrid\n                   Spain\n                   Tel:   +34 91 339 3535\n                   Email: Maria.C.Belinchon@ericsson.com\n\n                   Jose-Javier Pastor-Balbas\n                   R&D Department\n                   Ericsson Espana S. A.\n                   Via de los Poblados, 13\n                   28033 Madrid\n                   Spain\n                   Tel:   +34 91 339 1397\n            Email: J.Javier.Pastor@ericsson.com\n       ')
if mibBuilder.loadTexts: sctpMIB.setDescription('The MIB module for managing SCTP implementations.\n\n       Copyright (C) The Internet Society (2004).  This version of\n       this MIB module is part of RFC 3873; see the RFC itself for\n       full legal notices. ')
sctpObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 104, 1))
sctpStats = MibIdentifier((1, 3, 6, 1, 2, 1, 104, 1, 1))
sctpParams = MibIdentifier((1, 3, 6, 1, 2, 1, 104, 1, 2))
sctpCurrEstab = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 1), Gauge32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpCurrEstab.setDescription('The number of associations for which the current state is\n       either ESTABLISHED, SHUTDOWN-RECEIVED or SHUTDOWN-PENDING.')
sctpActiveEstabs = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpActiveEstabs.setDescription('The number of times that associations have made a direct\n       transition to the ESTABLISHED state from the COOKIE-ECHOED\n       state: COOKIE-ECHOED -> ESTABLISHED. The upper layer initiated\n       the association attempt.')
sctpPassiveEstabs = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpPassiveEstabs.setDescription('The number of times that associations have made a direct\n       transition to the ESTABLISHED state from the CLOSED state:\n       CLOSED -> ESTABLISHED. The remote endpoint initiated the\n       association attempt.')
sctpAborteds = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAborteds.setDescription("The number of times that associations have made a direct\n       transition to the CLOSED state from any state using the\n       primitive 'ABORT': AnyState --Abort--> CLOSED. Ungraceful\n       termination of the association.")
sctpShutdowns = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpShutdowns.setDescription('The number of times that associations have made a direct\n       transition to the CLOSED state from either the SHUTDOWN-SENT\n       state or the SHUTDOWN-ACK-SENT state. Graceful termination of\n       the association.')
sctpOutOfBlues = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpOutOfBlues.setDescription('The number of out of the blue packets received by the host.\n       An out of the blue packet is an SCTP packet correctly formed,\n       including the proper checksum, but for which the receiver was\n       unable to identify an appropriate association.')
sctpChecksumErrors = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpChecksumErrors.setDescription('The number of SCTP packets received with an invalid\n       checksum.')
sctpOutCtrlChunks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 8), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpOutCtrlChunks.setDescription('The number of SCTP control chunks sent (retransmissions are\n       not included). Control chunks are those chunks different from\n       DATA.')
sctpOutOrderChunks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 9), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpOutOrderChunks.setDescription('The number of SCTP ordered data chunks sent (retransmissions\n       are not included).')
sctpOutUnorderChunks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 10), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpOutUnorderChunks.setDescription('The number of SCTP unordered chunks (data chunks in which the\n       U bit is set to 1) sent (retransmissions are not included).')
sctpInCtrlChunks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 11), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpInCtrlChunks.setDescription('The number of SCTP control chunks received (no duplicate\n       chunks included).')
sctpInOrderChunks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 12), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpInOrderChunks.setDescription('The number of SCTP ordered data chunks received (no duplicate\n       chunks included).')
sctpInUnorderChunks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 13), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpInUnorderChunks.setDescription('The number of SCTP unordered chunks (data chunks in which the\n       U bit is set to 1) received (no duplicate chunks included).')
sctpFragUsrMsgs = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 14), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpFragUsrMsgs.setDescription('The number of user messages that have to be fragmented\n       because of the MTU.')
sctpReasmUsrMsgs = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 15), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpReasmUsrMsgs.setDescription('The number of user messages reassembled, after conversion\n       into DATA chunks.')
sctpOutSCTPPacks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 16), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpOutSCTPPacks.setDescription('The number of SCTP packets sent. Retransmitted DATA chunks\n       are included.')
sctpInSCTPPacks = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 17), Counter64()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpInSCTPPacks.setDescription('The number of SCTP packets received. Duplicates are\n       included.')
sctpDiscontinuityTime = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 1, 18), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpDiscontinuityTime.setDescription('The value of sysUpTime on the most recent occasion at which\n       any one or more of this general statistics counters suffered a\n       discontinuity.  The relevant counters are the specific\n       instances associated with this interface of any Counter32 or\n       Counter64 object contained in the SCTP layer statistics\n       (defined below sctpStats branch).  If no such discontinuities\n       have occurred since the last re-initialization of the local\n       management subsystem, then this object contains a zero value.')
sctpRtoAlgorithm = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 1), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2,))).clone(namedValues=NamedValues(("other", 1), ("vanj", 2),)).clone('vanj')).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpRtoAlgorithm.setDescription('The algorithm used to determine the timeout value (T3-rtx)\n       used for re-transmitting unacknowledged chunks.')
sctpRtoMin = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 2), Unsigned32().clone(1000)).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpRtoMin.setDescription("The minimum value permitted by a SCTP implementation for the\n       retransmission timeout value, measured in milliseconds.  More\n       refined semantics for objects of this type depend upon the\n       algorithm used to determine the retransmission timeout value.\n\n       A retransmission time value of zero means immediate\n       retransmission.\n\n       The value of this object has to be lower than or equal to\n       stcpRtoMax's value.")
sctpRtoMax = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 3), Unsigned32().clone(60000)).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpRtoMax.setDescription("The maximum value permitted by a SCTP implementation for the\n       retransmission timeout value, measured in milliseconds.  More\n       refined semantics for objects of this type depend upon the\n       algorithm used to determine the retransmission timeout value.\n\n       A retransmission time value of zero means immediate re-\n       transmission.\n\n\n\n       The value of this object has to be greater than or equal to\n       stcpRtoMin's value.")
sctpRtoInitial = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 4), Unsigned32().clone(3000)).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpRtoInitial.setDescription('The initial value for the retransmission timer.\n\n       A retransmission time value of zero means immediate re-\n       transmission.')
sctpMaxAssocs = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 5), Integer32().subtype(subtypeSpec=ConstraintsUnion(ValueRangeConstraint(-1,-1),ValueRangeConstraint(0,2147483647),))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpMaxAssocs.setDescription('The limit on the total number of associations the entity can\n       support. In entities where the maximum number of associations\n       is dynamic, this object should contain the value -1.')
sctpValCookieLife = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 6), Unsigned32().clone(60000)).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpValCookieLife.setDescription('Valid cookie life in the 4-way start-up handshake procedure.')
sctpMaxInitRetr = MibScalar((1, 3, 6, 1, 2, 1, 104, 1, 2, 7), Unsigned32().clone(8)).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpMaxInitRetr.setDescription('The maximum number of retransmissions at the start-up phase\n       (INIT and COOKIE ECHO chunks). ')
sctpAssocTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 3), )
if mibBuilder.loadTexts: sctpAssocTable.setDescription('A table containing SCTP association-specific information.')
sctpAssocEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 3, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocId"))
if mibBuilder.loadTexts: sctpAssocEntry.setDescription('General common variables and statistics for the whole\n       association.')
sctpAssocId = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: sctpAssocId.setDescription('Association Identification. Value identifying the\n       association. ')
sctpAssocRemHostName = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemHostName.setDescription("The peer's DNS name. This object needs to have the same\n       format as the encoding in the DNS protocol.  This implies that\n       the domain name can be up to 255 octets long, each octet being\n       0<=x<=255 as value with US-ASCII A-Z having a case insensitive\n       matching.\n\n       If no DNS domain name was received from the peer at init time\n       (embedded in the INIT or INIT-ACK chunk), this object is\n       meaningless. In such cases the object MUST contain a zero-\n       length string value. Otherwise, it contains the remote host\n       name received at init time.")
sctpAssocLocalPort = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 3), InetPortNumber().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocLocalPort.setDescription('The local SCTP port number used for this association.')
sctpAssocRemPort = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 4), InetPortNumber().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemPort.setDescription('The remote SCTP port number used for this association.')
sctpAssocRemPrimAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 5), InetAddressType()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemPrimAddrType.setDescription('The internet type of primary remote IP address. ')
sctpAssocRemPrimAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 6), InetAddress()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemPrimAddr.setDescription('The primary remote IP address. The type of this address is\n       determined by the value of sctpAssocRemPrimAddrType.\n\n       The client side will know this value after INIT_ACK message\n       reception, the server side will know this value when sending\n       INIT_ACK message. However, values will be filled in at\n       established(4) state.')
sctpAssocHeartBeatInterval = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 7), Unsigned32().clone(30000)).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocHeartBeatInterval.setDescription('The current heartbeat interval..\n\n       Zero value means no HeartBeat, even when the concerned\n       sctpAssocRemAddrHBFlag object is true.')
sctpAssocState = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 8), Integer32().subtype(subtypeSpec=ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9,))).clone(namedValues=NamedValues(("closed", 1), ("cookieWait", 2), ("cookieEchoed", 3), ("established", 4), ("shutdownPending", 5), ("shutdownSent", 6), ("shutdownReceived", 7), ("shutdownAckSent", 8), ("deleteTCB", 9),))).setMaxAccess("readwrite")
if mibBuilder.loadTexts: sctpAssocState.setDescription('The state of this SCTP association.\n\n       As in TCP, deleteTCB(9) is the only value that may be set by a\n       management station. If any other value is received, then the\n       agent must return a wrongValue error.\n\n       If a management station sets this object to the value\n       deleteTCB(9), then this has the effect of deleting the TCB (as\n       defined in SCTP) of the corresponding association on the\n       managed node, resulting in immediate termination of the\n       association.\n\n       As an implementation-specific option, an ABORT chunk may be\n       sent from the managed node to the other SCTP endpoint as a\n       result of setting the deleteTCB(9) value. The ABORT chunk\n       implies an ungraceful association shutdown.')
sctpAssocInStreams = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 9), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocInStreams.setDescription('Inbound Streams according to the negotiation at association\n       start up.')
sctpAssocOutStreams = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 10), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,65535))).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocOutStreams.setDescription('Outbound Streams according to the negotiation at association\n       start up. ')
sctpAssocMaxRetr = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 11), Unsigned32().clone(10)).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocMaxRetr.setDescription('The maximum number of data retransmissions in the association\n       context. This value is specific for each association and the\n       upper layer can change it by calling the appropriate\n       primitives. This value has to be smaller than the addition of\n       all the maximum number for all the paths\n       (sctpAssocRemAddrMaxPathRtx).\n\n       A value of zero value means no retransmissions.')
sctpAssocPrimProcess = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 12), Unsigned32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocPrimProcess.setDescription("This object identifies the system level process which holds\n       primary responsibility for the SCTP association.\n       Wherever possible, this should be the system's native unique\n       identification number. The special value 0 can be used to\n       indicate that no primary process is known.\n\n       Note that the value of this object can be used as a pointer\n       into the swRunTable of the HOST-RESOURCES-MIB(if the value is\n       smaller than 2147483647) or into the sysApplElmtRunTable of\n       the SYSAPPL-MIB.")
sctpAssocT1expireds = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 13), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocT1expireds.setDescription('The T1 timer determines how long to wait for an\n       acknowledgement after sending an INIT or COOKIE-ECHO chunk.\n       This object reflects the number of times the T1 timer expires\n       without having received the acknowledgement.\n\n       Discontinuities in the value of this counter can occur at re-\n       initialization of the management system, and at other times as\n       indicated by the value of sctpAssocDiscontinuityTime.')
sctpAssocT2expireds = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 14), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocT2expireds.setDescription('The T2 timer determines how long to wait for an\n       acknowledgement after sending a SHUTDOWN or SHUTDOWN-ACK\n       chunk. This object reflects the number of times that T2- timer\n       expired.\n\n       Discontinuities in the value of this counter can occur at re-\n       initialization of the management system, and at other times as\n       indicated by the value of sctpAssocDiscontinuityTime.')
sctpAssocRtxChunks = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 15), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRtxChunks.setDescription('When T3-rtx expires, the DATA chunks that triggered the T3\n       timer will be re-sent according with the retransmissions\n       rules. Every DATA chunk that was included in the SCTP packet\n       that triggered the T3-rtx timer must be added to the value of\n       this counter.\n\n       Discontinuities in the value of this counter can occur at re-\n       initialization of the management system, and at other times as\n       indicated by the value of sctpAssocDiscontinuityTime.')
sctpAssocStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 16), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocStartTime.setDescription('The value of sysUpTime at the time that the association\n       represented by this row enters the ESTABLISHED state, i.e.,\n       the sctpAssocState object is set to established(4). The\n       value of this object will be zero:\n       - before the association enters the established(4)\n         state, or\n\n\n       - if the established(4) state was entered prior to\n         the last re-initialization of the local network management\n         subsystem.')
sctpAssocDiscontinuityTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 3, 1, 17), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocDiscontinuityTime.setDescription('The value of sysUpTime on the most recent occasion at which\n       any one or more of this SCTP association counters suffered a\n       discontinuity.  The relevant counters are the specific\n       instances associated with this interface of any Counter32 or\n       Counter64 object contained in the sctpAssocTable or\n       sctpLocalAddrTable or sctpRemAddrTable.  If no such\n       discontinuities have occurred since the last re-initialization\n       of the local management subsystem, then this object contains a\n       zero value. ')
sctpAssocLocalAddrTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 4), )
if mibBuilder.loadTexts: sctpAssocLocalAddrTable.setDescription('Expanded table of sctpAssocTable based on the AssocId index.\n       This table shows data related to each local IP address which\n       is used by this association.')
sctpAssocLocalAddrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 4, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocId"), (0, "SCTP-MIB", "sctpAssocLocalAddrType"), (0, "SCTP-MIB", "sctpAssocLocalAddr"))
if mibBuilder.loadTexts: sctpAssocLocalAddrEntry.setDescription('Local information about the available addresses. There will\n       be an entry for every local IP address defined for this\n\n       association.\n       Implementors need to be aware that if the size of\n       sctpAssocLocalAddr exceeds 114 octets then OIDs of column\n       instances in this table will have more than 128 sub-\n       identifiers and cannot be accessed using SNMPv1, SNMPv2c, or\n       SNMPv3.')
sctpAssocLocalAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 4, 1, 1), InetAddressType())
if mibBuilder.loadTexts: sctpAssocLocalAddrType.setDescription('Internet type of local IP address used for this association.')
sctpAssocLocalAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 4, 1, 2), InetAddress())
if mibBuilder.loadTexts: sctpAssocLocalAddr.setDescription('The value of a local IP address available for this\n       association. The type of this address is determined by the\n       value of sctpAssocLocalAddrType.')
sctpAssocLocalAddrStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 4, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocLocalAddrStartTime.setDescription('The value of sysUpTime at the time that this row was\n       created.')
sctpAssocRemAddrTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 5), )
if mibBuilder.loadTexts: sctpAssocRemAddrTable.setDescription('Expanded table of sctpAssocTable based on the AssocId index.\n       This table shows data related to each remote peer IP address\n       which is used by this association.')
sctpAssocRemAddrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 5, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocId"), (0, "SCTP-MIB", "sctpAssocRemAddrType"), (0, "SCTP-MIB", "sctpAssocRemAddr"))
if mibBuilder.loadTexts: sctpAssocRemAddrEntry.setDescription('Information about the most important variables for every\n       remote IP address. There will be an entry for every remote IP\n       address defined for this association.\n\n       Implementors need to be aware that if the size of\n       sctpAssocRemAddr exceeds 114 octets then OIDs of column\n       instances in this table will have more than 128 sub-\n       identifiers and cannot be accessed using SNMPv1, SNMPv2c, or\n       SNMPv3.')
sctpAssocRemAddrType = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 1), InetAddressType())
if mibBuilder.loadTexts: sctpAssocRemAddrType.setDescription('Internet type of a remote IP address available for this\n       association.')
sctpAssocRemAddr = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 2), InetAddress())
if mibBuilder.loadTexts: sctpAssocRemAddr.setDescription('The value of a remote IP address available for this\n       association. The type of this address is determined by the\n       value of sctpAssocLocalAddrType.')
sctpAssocRemAddrActive = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 3), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemAddrActive.setDescription("This object gives information about the reachability of this\n       specific remote IP address.\n\n       When the object is set to 'true' (1), the remote IP address is\n       understood as Active. Active means that the threshold of no\n       answers received from this IP address has not been reached.\n\n\n\n\n       When the object is set to 'false' (2), the remote IP address\n       is understood as Inactive. Inactive means that either no\n       heartbeat or any other message was received from this address,\n       reaching the threshold defined by the protocol.")
sctpAssocRemAddrHBActive = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 4), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemAddrHBActive.setDescription('This object indicates whether the optional Heartbeat check\n       associated to one destination transport address is activated\n       or not (value equal to true or false, respectively). ')
sctpAssocRemAddrRTO = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 5), Unsigned32()).setUnits('milliseconds').setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemAddrRTO.setDescription('The current Retransmission Timeout. T3-rtx timer as defined\n       in the protocol SCTP.')
sctpAssocRemAddrMaxPathRtx = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 6), Unsigned32().clone(5)).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemAddrMaxPathRtx.setDescription('Maximum number of DATA chunks retransmissions allowed to a\n       remote IP address before it is considered inactive, as defined\n       in RFC2960.')
sctpAssocRemAddrRtx = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemAddrRtx.setDescription('Number of DATA chunks retransmissions to this specific IP\n       address. When T3-rtx expires, the DATA chunk that triggered\n       the T3 timer will be re-sent according to the retransmissions\n       rules. Every DATA chunk that is included in a SCTP packet and\n       was transmitted to this specific IP address before, will be\n       included in this counter.\n\n       Discontinuities in the value of this counter can occur at re-\n       initialization of the management system, and at other times as\n       indicated by the value of sctpAssocDiscontinuityTime.')
sctpAssocRemAddrStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 5, 1, 8), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpAssocRemAddrStartTime.setDescription('The value of sysUpTime at the time that this row was\n       created.')
sctpLookupLocalPortTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 6), )
if mibBuilder.loadTexts: sctpLookupLocalPortTable.setDescription('With the use of this table, a list of associations which are\n\n       using the specified local port can be retrieved.')
sctpLookupLocalPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 6, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocLocalPort"), (0, "SCTP-MIB", "sctpAssocId"))
if mibBuilder.loadTexts: sctpLookupLocalPortEntry.setDescription('This table is indexed by local port and association ID.\n       Specifying a local port, we would get a list of the\n       associations whose local port is the one specified.')
sctpLookupLocalPortStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 6, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpLookupLocalPortStartTime.setDescription('The value of sysUpTime at the time that this row was created.\n\n       As the table will be created after the sctpAssocTable\n       creation, this value could be equal to the sctpAssocStartTime\n       object from the main table.')
sctpLookupRemPortTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 7), )
if mibBuilder.loadTexts: sctpLookupRemPortTable.setDescription('With the use of this table, a list of associations which are\n       using the specified remote port can be got')
sctpLookupRemPortEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 7, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocRemPort"), (0, "SCTP-MIB", "sctpAssocId"))
if mibBuilder.loadTexts: sctpLookupRemPortEntry.setDescription('This table is indexed by remote port and association ID.\n       Specifying a remote port we would get a list of the\n       associations whose local port is the one specified ')
sctpLookupRemPortStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 7, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpLookupRemPortStartTime.setDescription('The value of sysUpTime at the time that this row was created.\n\n       As the table will be created after the sctpAssocTable\n       creation, this value could be equal to the sctpAssocStartTime\n       object from the main table.')
sctpLookupRemHostNameTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 8), )
if mibBuilder.loadTexts: sctpLookupRemHostNameTable.setDescription('With the use of this table, a list of associations with that\n       particular host can be retrieved.')
sctpLookupRemHostNameEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 8, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocRemHostName"), (0, "SCTP-MIB", "sctpAssocId"))
if mibBuilder.loadTexts: sctpLookupRemHostNameEntry.setDescription('This table is indexed by remote host name and association ID.\n       Specifying a host name we would get a list of the associations\n       specifying that host name as the remote one.\n\n       Implementors need to be aware that if the size of\n       sctpAssocRemHostName exceeds 115 octets then OIDs of column\n       instances in this table will have more than 128 sub-\n       identifiers and cannot be accessed using SNMPv1, SNMPv2c, or\n       SNMPv3.')
sctpLookupRemHostNameStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 8, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpLookupRemHostNameStartTime.setDescription('The value of sysUpTime at the time that this row was created.\n\n       As the table will be created after the sctpAssocTable\n       creation, this value could be equal to the sctpAssocStartTime\n       object from the main table.')
sctpLookupRemPrimIPAddrTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 9), )
if mibBuilder.loadTexts: sctpLookupRemPrimIPAddrTable.setDescription('With the use of this table, a list of associations that have\n       the specified IP address as primary within the remote set of\n       active addresses can be retrieved.')
sctpLookupRemPrimIPAddrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 9, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocRemPrimAddrType"), (0, "SCTP-MIB", "sctpAssocRemPrimAddr"), (0, "SCTP-MIB", "sctpAssocId"))
if mibBuilder.loadTexts: sctpLookupRemPrimIPAddrEntry.setDescription('This table is indexed by primary address and association ID.\n       Specifying a primary address, we would get a list of the\n       associations that have the specified remote IP address marked\n       as primary.\n       Implementors need to be aware that if the size of\n       sctpAssocRemPrimAddr exceeds 114 octets then OIDs of column\n       instances in this table will have more than 128 sub-\n       identifiers and cannot be accessed using SNMPv1, SNMPv2c, or\n       SNMPv3.')
sctpLookupRemPrimIPAddrStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 9, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpLookupRemPrimIPAddrStartTime.setDescription('The value of SysUpTime at the time that this row was created.\n\n       As the table will be created after the sctpAssocTable\n       creation, this value could be equal to the sctpAssocStartTime\n       object from the main table.')
sctpLookupRemIPAddrTable = MibTable((1, 3, 6, 1, 2, 1, 104, 1, 10), )
if mibBuilder.loadTexts: sctpLookupRemIPAddrTable.setDescription('With the use of this table, a list of associations that have\n       the specified IP address as one of the remote ones can be\n       retrieved. ')
sctpLookupRemIPAddrEntry = MibTableRow((1, 3, 6, 1, 2, 1, 104, 1, 10, 1), ).setIndexNames((0, "SCTP-MIB", "sctpAssocRemAddrType"), (0, "SCTP-MIB", "sctpAssocRemAddr"), (0, "SCTP-MIB", "sctpAssocId"))
if mibBuilder.loadTexts: sctpLookupRemIPAddrEntry.setDescription('This table is indexed by a remote IP address and association\n       ID. Specifying an IP address we would get a list of the\n       associations that have the specified IP address included\n       within the set of remote IP addresses.')
sctpLookupRemIPAddrStartTime = MibTableColumn((1, 3, 6, 1, 2, 1, 104, 1, 10, 1, 1), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: sctpLookupRemIPAddrStartTime.setDescription('The value of SysUpTime at the time that this row was created.\n\n       As the table will be created after the sctpAssocTable\n       creation, this value could be equal to the sctpAssocStartTime\n       object from the main table.')
sctpMibConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 104, 2))
sctpMibCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 104, 2, 1))
sctpMibGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 104, 2, 2))
sctpLayerParamsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 104, 2, 2, 1)).setObjects(*(("SCTP-MIB", "sctpRtoAlgorithm"), ("SCTP-MIB", "sctpRtoMin"), ("SCTP-MIB", "sctpRtoMax"), ("SCTP-MIB", "sctpRtoInitial"), ("SCTP-MIB", "sctpMaxAssocs"), ("SCTP-MIB", "sctpValCookieLife"), ("SCTP-MIB", "sctpMaxInitRetr"),))
if mibBuilder.loadTexts: sctpLayerParamsGroup.setDescription('Common parameters for the SCTP layer, i.e., for all the\n       associations. They can usually be referred to as configuration\n       parameters.')
sctpStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 104, 2, 2, 2)).setObjects(*(("SCTP-MIB", "sctpCurrEstab"), ("SCTP-MIB", "sctpActiveEstabs"), ("SCTP-MIB", "sctpPassiveEstabs"), ("SCTP-MIB", "sctpAborteds"), ("SCTP-MIB", "sctpShutdowns"), ("SCTP-MIB", "sctpOutOfBlues"), ("SCTP-MIB", "sctpChecksumErrors"), ("SCTP-MIB", "sctpOutCtrlChunks"), ("SCTP-MIB", "sctpOutOrderChunks"), ("SCTP-MIB", "sctpOutUnorderChunks"), ("SCTP-MIB", "sctpInCtrlChunks"), ("SCTP-MIB", "sctpInOrderChunks"), ("SCTP-MIB", "sctpInUnorderChunks"), ("SCTP-MIB", "sctpFragUsrMsgs"), ("SCTP-MIB", "sctpReasmUsrMsgs"), ("SCTP-MIB", "sctpOutSCTPPacks"), ("SCTP-MIB", "sctpInSCTPPacks"), ("SCTP-MIB", "sctpDiscontinuityTime"), ("SCTP-MIB", "sctpAssocT1expireds"), ("SCTP-MIB", "sctpAssocT2expireds"), ("SCTP-MIB", "sctpAssocRtxChunks"), ("SCTP-MIB", "sctpAssocRemAddrRtx"),))
if mibBuilder.loadTexts: sctpStatsGroup.setDescription('Statistics group. It includes the objects to collect state\n       changes in the SCTP protocol local layer and flow control\n       statistics.')
sctpPerAssocParamsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 104, 2, 2, 3)).setObjects(*(("SCTP-MIB", "sctpAssocRemHostName"), ("SCTP-MIB", "sctpAssocLocalPort"), ("SCTP-MIB", "sctpAssocRemPort"), ("SCTP-MIB", "sctpAssocRemPrimAddrType"), ("SCTP-MIB", "sctpAssocRemPrimAddr"), ("SCTP-MIB", "sctpAssocHeartBeatInterval"), ("SCTP-MIB", "sctpAssocState"), ("SCTP-MIB", "sctpAssocInStreams"), ("SCTP-MIB", "sctpAssocOutStreams"), ("SCTP-MIB", "sctpAssocMaxRetr"), ("SCTP-MIB", "sctpAssocPrimProcess"), ("SCTP-MIB", "sctpAssocStartTime"), ("SCTP-MIB", "sctpAssocDiscontinuityTime"), ("SCTP-MIB", "sctpAssocLocalAddrStartTime"), ("SCTP-MIB", "sctpAssocRemAddrActive"), ("SCTP-MIB", "sctpAssocRemAddrHBActive"), ("SCTP-MIB", "sctpAssocRemAddrRTO"), ("SCTP-MIB", "sctpAssocRemAddrMaxPathRtx"), ("SCTP-MIB", "sctpAssocRemAddrStartTime"),))
if mibBuilder.loadTexts: sctpPerAssocParamsGroup.setDescription('The SCTP group of objects to manage per-association\n       parameters. These variables include all the SCTP basic\n       features.')
sctpPerAssocStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 104, 2, 2, 4)).setObjects(*(("SCTP-MIB", "sctpAssocT1expireds"), ("SCTP-MIB", "sctpAssocT2expireds"), ("SCTP-MIB", "sctpAssocRtxChunks"), ("SCTP-MIB", "sctpAssocRemAddrRtx"),))
if mibBuilder.loadTexts: sctpPerAssocStatsGroup.setDescription('Per Association Statistics group. It includes the objects to\n       collect flow control statistics per association.')
sctpInverseGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 104, 2, 2, 5)).setObjects(*(("SCTP-MIB", "sctpLookupLocalPortStartTime"), ("SCTP-MIB", "sctpLookupRemPortStartTime"), ("SCTP-MIB", "sctpLookupRemHostNameStartTime"), ("SCTP-MIB", "sctpLookupRemPrimIPAddrStartTime"), ("SCTP-MIB", "sctpLookupRemIPAddrStartTime"),))
if mibBuilder.loadTexts: sctpInverseGroup.setDescription('Objects used in the inverse lookup tables.')
sctpMibCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 104, 2, 1, 1)).setObjects(*(("SCTP-MIB", "sctpLayerParamsGroup"), ("SCTP-MIB", "sctpPerAssocParamsGroup"), ("SCTP-MIB", "sctpStatsGroup"), ("SCTP-MIB", "sctpPerAssocStatsGroup"),))
if mibBuilder.loadTexts: sctpMibCompliance.setDescription('The compliance statement for SNMP entities which implement\n       this SCTP MIB Module.\n\n       There are a number of INDEX objects that cannot be represented\n       in the form of OBJECT clauses in SMIv2, but for which we have\n       the following compliance requirements, expressed in OBJECT\n       clause form in this description clause:\n\n-- OBJECT        sctpAssocLocalAddrType\n-- SYNTAX        InetAddressType {ipv4(1), ipv6(2)}\n-- DESCRIPTION\n--       It is only required to have IPv4 and IPv6 addresses without\n--       zone indices.\n--       The address with zone indices is required if an\n--       implementation can connect multiple zones.\n--\n-- OBJECT        sctpAssocLocalAddr\n-- SYNTAX        InetAddress (SIZE(4|16))\n-- DESCRIPTION\n--       An implementation is only required to support globally\n--       unique IPv4 and IPv6 addresses.\n--\n-- OBJECT        sctpAssocRemAddrType\n-- SYNTAX        InetAddressType {ipv4(1), ipv6(2)}\n-- DESCRIPTION\n--       It is only required to have IPv4 and IPv6 addresses without\n--       zone indices.\n--       The address with zone indices is required if an\n--       implementation can connect multiple zones.\n--\n-- OBJECT        sctpAssocRemAddr\n-- SYNTAX        InetAddress (SIZE(4|16))\n-- DESCRIPTION\n--       An implementation is only required to support globally\n--       unique IPv4 and IPv6 addresses.\n--\n       ')
mibBuilder.exportSymbols("SCTP-MIB", sctpLookupRemIPAddrStartTime=sctpLookupRemIPAddrStartTime, sctpAssocEntry=sctpAssocEntry, sctpOutUnorderChunks=sctpOutUnorderChunks, sctpAssocT2expireds=sctpAssocT2expireds, sctpShutdowns=sctpShutdowns, sctpRtoMax=sctpRtoMax, sctpAborteds=sctpAborteds, sctpLookupRemPortEntry=sctpLookupRemPortEntry, sctpLookupRemIPAddrTable=sctpLookupRemIPAddrTable, sctpLookupRemPrimIPAddrStartTime=sctpLookupRemPrimIPAddrStartTime, sctpMibCompliance=sctpMibCompliance, sctpMaxInitRetr=sctpMaxInitRetr, sctpAssocDiscontinuityTime=sctpAssocDiscontinuityTime, sctpAssocTable=sctpAssocTable, sctpMaxAssocs=sctpMaxAssocs, sctpLookupRemPrimIPAddrTable=sctpLookupRemPrimIPAddrTable, sctpValCookieLife=sctpValCookieLife, sctpLookupRemIPAddrEntry=sctpLookupRemIPAddrEntry, sctpMibConformance=sctpMibConformance, sctpLookupLocalPortEntry=sctpLookupLocalPortEntry, sctpLookupRemHostNameStartTime=sctpLookupRemHostNameStartTime, sctpFragUsrMsgs=sctpFragUsrMsgs, sctpObjects=sctpObjects, sctpAssocRemPrimAddr=sctpAssocRemPrimAddr, sctpAssocLocalAddrEntry=sctpAssocLocalAddrEntry, sctpReasmUsrMsgs=sctpReasmUsrMsgs, sctpRtoMin=sctpRtoMin, sctpStatsGroup=sctpStatsGroup, sctpLookupLocalPortStartTime=sctpLookupLocalPortStartTime, sctpMibCompliances=sctpMibCompliances, sctpAssocLocalAddr=sctpAssocLocalAddr, sctpActiveEstabs=sctpActiveEstabs, sctpPerAssocStatsGroup=sctpPerAssocStatsGroup, sctpLookupRemPortTable=sctpLookupRemPortTable, sctpAssocStartTime=sctpAssocStartTime, sctpOutSCTPPacks=sctpOutSCTPPacks, sctpAssocState=sctpAssocState, sctpInCtrlChunks=sctpInCtrlChunks, sctpInUnorderChunks=sctpInUnorderChunks, sctpAssocRemHostName=sctpAssocRemHostName, sctpAssocOutStreams=sctpAssocOutStreams, sctpInSCTPPacks=sctpInSCTPPacks, sctpAssocRemAddrStartTime=sctpAssocRemAddrStartTime, sctpInOrderChunks=sctpInOrderChunks, sctpAssocRemPort=sctpAssocRemPort, sctpLookupRemHostNameEntry=sctpLookupRemHostNameEntry, sctpMibGroups=sctpMibGroups, sctpAssocRemAddr=sctpAssocRemAddr, sctpAssocRemAddrEntry=sctpAssocRemAddrEntry, sctpRtoInitial=sctpRtoInitial, sctpAssocRemAddrRtx=sctpAssocRemAddrRtx, sctpStats=sctpStats, sctpAssocLocalAddrType=sctpAssocLocalAddrType, sctpDiscontinuityTime=sctpDiscontinuityTime, sctpLookupLocalPortTable=sctpLookupLocalPortTable, sctpAssocT1expireds=sctpAssocT1expireds, PYSNMP_MODULE_ID=sctpMIB, sctpAssocRemAddrTable=sctpAssocRemAddrTable, sctpAssocRemAddrRTO=sctpAssocRemAddrRTO, sctpAssocMaxRetr=sctpAssocMaxRetr, sctpAssocLocalPort=sctpAssocLocalPort, sctpAssocLocalAddrTable=sctpAssocLocalAddrTable, sctpAssocRemPrimAddrType=sctpAssocRemPrimAddrType, sctpAssocInStreams=sctpAssocInStreams, sctpAssocHeartBeatInterval=sctpAssocHeartBeatInterval, sctpOutOrderChunks=sctpOutOrderChunks, sctpOutCtrlChunks=sctpOutCtrlChunks, sctpAssocRemAddrType=sctpAssocRemAddrType, sctpInverseGroup=sctpInverseGroup, sctpAssocPrimProcess=sctpAssocPrimProcess, sctpChecksumErrors=sctpChecksumErrors, sctpAssocRemAddrMaxPathRtx=sctpAssocRemAddrMaxPathRtx, sctpPassiveEstabs=sctpPassiveEstabs, sctpAssocId=sctpAssocId, sctpAssocRtxChunks=sctpAssocRtxChunks, sctpAssocLocalAddrStartTime=sctpAssocLocalAddrStartTime, sctpPerAssocParamsGroup=sctpPerAssocParamsGroup, sctpMIB=sctpMIB, sctpOutOfBlues=sctpOutOfBlues, sctpCurrEstab=sctpCurrEstab, sctpLookupRemHostNameTable=sctpLookupRemHostNameTable, sctpLookupRemPrimIPAddrEntry=sctpLookupRemPrimIPAddrEntry, sctpLayerParamsGroup=sctpLayerParamsGroup, sctpRtoAlgorithm=sctpRtoAlgorithm, sctpAssocRemAddrActive=sctpAssocRemAddrActive, sctpLookupRemPortStartTime=sctpLookupRemPortStartTime, sctpParams=sctpParams, sctpAssocRemAddrHBActive=sctpAssocRemAddrHBActive)



#
# PySNMP MIB module ETHER-CHIPSET-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/ETHER-CHIPSET-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:11:58 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, OctetString, Integer, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "OctetString", "Integer")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ValueSizeConstraint, ConstraintsUnion, SingleValueConstraint, ValueRangeConstraint, ConstraintsIntersection, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ValueSizeConstraint", "ConstraintsUnion", "SingleValueConstraint", "ValueRangeConstraint", "ConstraintsIntersection")
( dot3, ) = mibBuilder.importSymbols("EtherLike-MIB", "dot3")
( NotificationGroup, ModuleCompliance, ) = mibBuilder.importSymbols("SNMPv2-CONF", "NotificationGroup", "ModuleCompliance")
( iso, Counter64, ModuleIdentity, MibScalar, MibTable, MibTableRow, MibTableColumn, Unsigned32, IpAddress, mib_2, TimeTicks, ObjectIdentity, Gauge32, Counter32, NotificationType, MibIdentifier, Integer32, Bits, ) = mibBuilder.importSymbols("SNMPv2-SMI", "iso", "Counter64", "ModuleIdentity", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Unsigned32", "IpAddress", "mib-2", "TimeTicks", "ObjectIdentity", "Gauge32", "Counter32", "NotificationType", "MibIdentifier", "Integer32", "Bits")
( TextualConvention, DisplayString, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString")
etherChipsetMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 70)).setRevisions(("1999-08-24 04:00",))
if mibBuilder.loadTexts: etherChipsetMIB.setLastUpdated('9908240400Z')
if mibBuilder.loadTexts: etherChipsetMIB.setOrganization('IETF 802.3 Hub MIB Working Group')
if mibBuilder.loadTexts: etherChipsetMIB.setContactInfo('WG E-mail: hubmib@hprnd.rose.hp.com\n             To subscribe: hubmib-request@hprnd.rose.hp.com\n\n                    Chair: Dan Romascanu\n                   Postal: Lucent Technologies\n                           Atidum Technology Park, Bldg. 3\n                           Tel Aviv 61131\n                           Israel\n                      Tel: +972 3 645 8414\n                   E-mail: dromasca@lucent.com\n\n                  Editor: John Flick\n                  Postal: Hewlett-Packard Company\n                          8000 Foothills Blvd. M/S 5556\n                          Roseville, CA 95747-5556\n                          USA\n\n                     Tel: +1 916 785 4018\n                     Fax: +1 916 785 3583\n                  E-mail: johnf@rose.hp.com')
if mibBuilder.loadTexts: etherChipsetMIB.setDescription('This MIB module contains registered values for\n                       use by the dot3StatsEtherChipSet object in\n                       the EtherLike-MIB.  This object is used to\n                       identify the MAC hardware used to communicate\n                       on an interface.\n\n                       Note that the dot3StatsEtherChipSet object\n                       has been deprecated.  The primary purpose of\n                       this module is to capture historic assignments\n                       made by the various IETF working groups that\n                       have been responsible for maintaining the\n                       EtherLike-MIB.  Implementations which support\n                       the dot3StatsEtherChipSet object for backwards\n                       compatability may continue to use these values.\n                       For those chipsets not represented in this\n                       module, registration is required in other\n                       documentation, e.g., assignment within that\n                       part of the registration tree delegated to\n                       individual enterprises (see RFC 1155 and RFC\n                       1902).')
dot3ChipSets = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8))
dot3ChipSetAMD = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 1))
dot3ChipSetAMD7990 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 1))
if mibBuilder.loadTexts: dot3ChipSetAMD7990.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am7990 Local Area Network\n                       Controller for Ethernet (LANCE).')
dot3ChipSetAMD79900 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 2))
if mibBuilder.loadTexts: dot3ChipSetAMD79900.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79900 chip.')
dot3ChipSetAMD79C940 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 3))
if mibBuilder.loadTexts: dot3ChipSetAMD79C940.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C940 Media Access Controller\n                       for Ethernet (MACE).')
dot3ChipSetAMD79C90 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 4))
if mibBuilder.loadTexts: dot3ChipSetAMD79C90.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C90 CMOS Local Area Network\n                       Controller for Ethernet (C-LANCE).')
dot3ChipSetAMD79C960 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 5))
if mibBuilder.loadTexts: dot3ChipSetAMD79C960.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C960 PCnet-ISA Single Chip\n                       Ethernet Controller for ISA.')
dot3ChipSetAMD79C961 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 6))
if mibBuilder.loadTexts: dot3ChipSetAMD79C961.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C961 PCnet-ISA+ Single Chip\n                       Plug & Play Full-Duplex Ethernet Controller\n                       for ISA.')
dot3ChipSetAMD79C961A = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 7))
if mibBuilder.loadTexts: dot3ChipSetAMD79C961A.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C961A PCnet-ISA II Single Chip\n                       Plug & Play Full-Duplex Ethernet Controller\n                       for ISA.')
dot3ChipSetAMD79C965 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 8))
if mibBuilder.loadTexts: dot3ChipSetAMD79C965.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C965 PCnet-32 Single Chip\n                       Ethernet Controller for PCI.')
dot3ChipSetAMD79C970 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 9))
if mibBuilder.loadTexts: dot3ChipSetAMD79C970.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C970 PCnet PCI Single Chip\n                       Ethernet Controller for PCI Local Bus.')
dot3ChipSetAMD79C970A = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 10))
if mibBuilder.loadTexts: dot3ChipSetAMD79C970A.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices AM79C970A PCnet PCI II Single Chip\n                       Full-Duplex Ethernet Controller for PCI Local\n                       Bus.')
dot3ChipSetAMD79C971 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 11))
if mibBuilder.loadTexts: dot3ChipSetAMD79C971.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C971 PCnet-FAST Single Chip\n                       Full-Duplex 10/100 Mbps Ethernet Controller for\n                       PCI Local Bus.')
dot3ChipSetAMD79C972 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 1, 12))
if mibBuilder.loadTexts: dot3ChipSetAMD79C972.setDescription('The authoritative identifier for the Advanced\n                       Micro Devices Am79C972 PCnet-FAST+ Enhanced\n                       10/100 Mbps PCI Ethernet Controller with OnNow\n                       Support.')
dot3ChipSetIntel = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 2))
dot3ChipSetIntel82586 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 2, 1))
if mibBuilder.loadTexts: dot3ChipSetIntel82586.setDescription('The authoritative identifier for the Intel\n                       82586 IEEE 802.3 Ethernet LAN Coprocessor.')
dot3ChipSetIntel82596 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 2, 2))
if mibBuilder.loadTexts: dot3ChipSetIntel82596.setDescription('The authoritative identifier for the Intel\n                       82596 High-Performance 32-Bit Local Area Network\n                       Coprocessor.')
dot3ChipSetIntel82595 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 2, 3))
if mibBuilder.loadTexts: dot3ChipSetIntel82595.setDescription('The authoritative identifier for the Intel\n                       82595 High Integration Ethernet Controller.')
dot3ChipSetIntel82557 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 2, 4))
if mibBuilder.loadTexts: dot3ChipSetIntel82557.setDescription('The authoritative identifier for the Intel\n                       82557 Fast Ethernet PCI Bus Lan Controller.')
dot3ChipSetIntel82558 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 2, 5))
if mibBuilder.loadTexts: dot3ChipSetIntel82558.setDescription('The authoritative identifier for the Intel\n                       82558 Fast Ethernet PCI Bus LAN Controller with\n                       Integrated PHY.')
dot3ChipSetSeeq = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 3))
dot3ChipSetSeeq8003 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 1))
if mibBuilder.loadTexts: dot3ChipSetSeeq8003.setDescription('The authoritative identifier for the SEEQ\n                       8003 chip set.')
dot3ChipSetSeeq80C03 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 2))
if mibBuilder.loadTexts: dot3ChipSetSeeq80C03.setDescription('The authoritative identifier for the SEEQ\n                       80C03 Full-Duplex CMOS Ethernet Data Link\n                       Controller (MAC).')
dot3ChipSetSeeq84C30 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 3))
if mibBuilder.loadTexts: dot3ChipSetSeeq84C30.setDescription('The authoritative identifier for the SEEQ\n                       4-Port 84C30 Full-Duplex CMOS Ethernet 10\n                       MBit/Sec Data Link Controller (MAC).')
dot3ChipSetSeeq8431 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 4))
if mibBuilder.loadTexts: dot3ChipSetSeeq8431.setDescription('The authoritative identifier for the SEEQ\n                       4-Port 8431 Full-Duplex CMOS Ethernet 10\n                       MBit/Sec Data Link Controller (MAC).')
dot3ChipSetSeeq80C300 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 5))
if mibBuilder.loadTexts: dot3ChipSetSeeq80C300.setDescription('The authoritative identifier for the SEEQ\n                       80C300 Full-Duplex CMOS Ethernet 10/100\n                       Mbit/Sec Data Link Controller (MAC).')
dot3ChipSetSeeq84C300 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 6))
if mibBuilder.loadTexts: dot3ChipSetSeeq84C300.setDescription('The authoritative identifier for the SEEQ\n                       4-Port 84C300 Fast Ethernet Controller (MAC).')
dot3ChipSetSeeq84301 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 7))
if mibBuilder.loadTexts: dot3ChipSetSeeq84301.setDescription('The authoritative identifier for the SEEQ\n                       4-Port 84301 Fast Ethernet Controller (MAC).')
dot3ChipSetSeeq84302 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 8))
if mibBuilder.loadTexts: dot3ChipSetSeeq84302.setDescription('The authoritative identifier for the SEEQ\n                       4-Port 84302 Fast Ethernet Controller (MAC).')
dot3ChipSetSeeq8100 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 3, 9))
if mibBuilder.loadTexts: dot3ChipSetSeeq8100.setDescription('The authoritative identifier for the SEEQ\n                       8100 Gigabit Ethernet Controller (MAC & PCS).')
dot3ChipSetNational = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 4))
dot3ChipSetNational8390 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 1))
if mibBuilder.loadTexts: dot3ChipSetNational8390.setDescription('The authoritative identifier for the National\n                       Semiconductor DP8390 Network Interface\n                       Controller.')
dot3ChipSetNationalSonic = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 2))
if mibBuilder.loadTexts: dot3ChipSetNationalSonic.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83932 Systems-Oriented Network\n                       Interface Controller (SONIC).')
dot3ChipSetNational83901 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 3))
if mibBuilder.loadTexts: dot3ChipSetNational83901.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83901 Serial Network Interface\n                       Controller (SNIC).')
dot3ChipSetNational83902 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 4))
if mibBuilder.loadTexts: dot3ChipSetNational83902.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83902 Serial Network Interface\n                       Controller for Twisted Pair (ST-NIC).')
dot3ChipSetNational83905 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 5))
if mibBuilder.loadTexts: dot3ChipSetNational83905.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83905 AT Local Area Network\n                       Twisted-Pair Interface (AT/LANTIC).')
dot3ChipSetNational83907 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 6))
if mibBuilder.loadTexts: dot3ChipSetNational83907.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83907 AT Twisted-Pair Enhanced\n                       Coaxial Network Interface Controller\n                       (AT/LANTIC II).')
dot3ChipSetNational83916 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 7))
if mibBuilder.loadTexts: dot3ChipSetNational83916.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83916 Systems-Oriented Network\n                       Interface Controller (SONIC-16).')
dot3ChipSetNational83934 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 8))
if mibBuilder.loadTexts: dot3ChipSetNational83934.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83934 Systems-Oriented Network\n                       Interface Controller with Twisted Pair Interface\n                       (SONIC-T).')
dot3ChipSetNational83936 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 4, 9))
if mibBuilder.loadTexts: dot3ChipSetNational83936.setDescription('The authoritative identifier for the National\n                       Semiconductor DP83936AVUL Full-Duplex Systems-\n                       Oriented Network Interface Controller with\n                       Twisted Pair Interface (SONIC-T).')
dot3ChipSetFujitsu = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 5))
dot3ChipSetFujitsu86950 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 5, 1))
if mibBuilder.loadTexts: dot3ChipSetFujitsu86950.setDescription('The authoritative identifier for the Fujitsu\n                       86950 chip.')
dot3ChipSetFujitsu86960 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 5, 2))
if mibBuilder.loadTexts: dot3ChipSetFujitsu86960.setDescription('The authoritative identifier for the Fujitsu\n                       MB86960 Network Interface Controller with\n                       Encoder/Decoder (NICE).')
dot3ChipSetFujitsu86964 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 5, 3))
if mibBuilder.loadTexts: dot3ChipSetFujitsu86964.setDescription('The authoritative identifier for the Fujitsu\n                       MB86964 Ethernet Controller with 10BASE-T\n                       Tranceiver.')
dot3ChipSetFujitsu86965A = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 5, 4))
if mibBuilder.loadTexts: dot3ChipSetFujitsu86965A.setDescription('The authoritative identifier for the Fujitsu\n                       MB86965A EtherCoupler Single-Chip Ethernet\n                       Controller.')
dot3ChipSetFujitsu86965B = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 5, 5))
if mibBuilder.loadTexts: dot3ChipSetFujitsu86965B.setDescription('The authoritative identifier for the Fujitsu\n                       MB86965B EtherCoupler Single-Chip Ethernet\n                       Controller (supports full-duplex).')
dot3ChipSetDigital = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 6))
dot3ChipSetDigitalDC21040 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 1))
if mibBuilder.loadTexts: dot3ChipSetDigitalDC21040.setDescription('The authoritative identifier for the Digital\n                       Semiconductor DC21040 chip.')
dot3ChipSetDigital21041 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 2))
if mibBuilder.loadTexts: dot3ChipSetDigital21041.setDescription('The authoritative identifier for the Digital\n                       Semiconductor 21041 PCI Ethernet LAN\n                       Controller.')
dot3ChipSetDigital21140 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 3))
if mibBuilder.loadTexts: dot3ChipSetDigital21140.setDescription('The authoritative identifier for the Digital\n                       Semiconductor 21140 PCI Fast Ethernet LAN\n                       Controller.')
dot3ChipSetDigital21143 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 4))
if mibBuilder.loadTexts: dot3ChipSetDigital21143.setDescription('The authoritative identifier for the Digital\n                       Semiconductor 21143 PCI/CardBus 10/100-Mb/s\n                       Ethernet LAN Controller.')
dot3ChipSetDigital21340 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 5))
if mibBuilder.loadTexts: dot3ChipSetDigital21340.setDescription('The authoritative identifier for the Digital\n                       Semiconductor 21340 10/100-MB/s managed buffered\n                       port switch.')
dot3ChipSetDigital21440 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 6))
if mibBuilder.loadTexts: dot3ChipSetDigital21440.setDescription('The authoritative identifier for the Digital\n                       Semiconductor 21440 Multiport 10/100Mbps\n                       Ethernet Controller.')
dot3ChipSetDigital21540 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 6, 7))
if mibBuilder.loadTexts: dot3ChipSetDigital21540.setDescription('The authoritative identifier for the Digital\n                       Semiconductor 21540 PCI/CardBus Ethernet LAN\n                       Controller with Modem Interface.')
dot3ChipSetTI = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 7))
dot3ChipSetTIE100 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 7, 1))
if mibBuilder.loadTexts: dot3ChipSetTIE100.setDescription('The authoritative identifier for the Texas\n                       Instruments TNETE100 ThunderLAN PCI Fast\n                       Ethernet Controller.')
dot3ChipSetTIE110 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 7, 2))
if mibBuilder.loadTexts: dot3ChipSetTIE110.setDescription('The authoritative identifier for the Texas\n                       Instruments TNETE110 ThunderLAN PCI 10BASE-T\n                       Ethernet Adapter.')
dot3ChipSetTIX3100 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 7, 3))
if mibBuilder.loadTexts: dot3ChipSetTIX3100.setDescription('The authoritative identifier for the Texas\n                       Instruments TNETX3100 Desktop ThunderSWITCH\n                       8/2.')
dot3ChipSetTIX3150 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 7, 4))
if mibBuilder.loadTexts: dot3ChipSetTIX3150.setDescription('The authoritative identifier for the Texas\n                       Instruments TNETX3150 ThunderSWITCH 12/3.')
dot3ChipSetTIX3270 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 7, 5))
if mibBuilder.loadTexts: dot3ChipSetTIX3270.setDescription('The authoritative identifier for the Texas\n                       Instruments TNETX3270 ThunderSWITCH 24/3.')
dot3ChipSetToshiba = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 8))
dot3ChipSetToshibaTC35815F = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 8, 1))
if mibBuilder.loadTexts: dot3ChipSetToshibaTC35815F.setDescription('The authoritative identifier for the Toshiba\n                       TC35815F PCI-Based 100/10Mbps Ethernet\n                       Controller.')
dot3ChipSetLucent = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 9))
dot3ChipSetLucentATT1MX10 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 9, 1))
if mibBuilder.loadTexts: dot3ChipSetLucentATT1MX10.setDescription('The authoritative identifier for the Lucent\n                       Technologies ATT1MX10 (Spinnaker) Quad MAC and\n                       Tranceiver for Ethernet Frame Switching.')
dot3ChipSetLucentLUC3M08 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 9, 2))
if mibBuilder.loadTexts: dot3ChipSetLucentLUC3M08.setDescription('The authoritative identifier for the Lucent\n                       Technologies LUC3M08 Eight Ethernet MACs for\n                       10/100 Mbits/s Frame Switching.')
dot3ChipSetGalileo = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 10))
dot3ChipSetGalileoGT48001 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 10, 1))
if mibBuilder.loadTexts: dot3ChipSetGalileoGT48001.setDescription('The authoritative identifier for the Galileo\n                       Technology GT-48001A Switched Ethernet\n                       Controller.')
dot3ChipSetGalileoGT48002 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 10, 2))
if mibBuilder.loadTexts: dot3ChipSetGalileoGT48002.setDescription('The authoritative identifier for the Galileo\n                       Technology GT-48002A Switched Fast Ethernet\n                       Controller.')
dot3ChipSetGalileoGT48004 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 10, 3))
if mibBuilder.loadTexts: dot3ChipSetGalileoGT48004.setDescription('The authoritative identifier for the Galileo\n                       Technology GT-48004A Four Port Fast Ethernet\n                       Switch for Multiport 10/100BASE-X Systems.')
dot3ChipSetGalileoGT48207 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 10, 4))
if mibBuilder.loadTexts: dot3ChipSetGalileoGT48207.setDescription('The authoritative identifier for the Galileo\n                       Technology GT-48207 Low-Cost 10 Port Switched\n                       Ethernet Controller for 10+10/100BASE-X.')
dot3ChipSetGalileoGT48208 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 10, 5))
if mibBuilder.loadTexts: dot3ChipSetGalileoGT48208.setDescription('The authoritative identifier for the Galileo\n                       Technology GT-48208 Advanced 10 Port Switched\n                       Ethernet Controller for 10+10/100BASE-X.')
dot3ChipSetGalileoGT48212 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 10, 6))
if mibBuilder.loadTexts: dot3ChipSetGalileoGT48212.setDescription('The authoritative identifier for the Galileo\n                       Technology GT-48212 Advanced 14 Port Switched\n                       Ethernet Controller for 10+10/100BASE-X.')
dot3ChipSetJato = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 11))
dot3ChipSetJatoJT1001 = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 11, 1))
if mibBuilder.loadTexts: dot3ChipSetJatoJT1001.setDescription('The authoritative identifier for the Jato\n                       Technologies JT1001 GigEMAC Server\n                       10/100/1000Mbps Ethernet Controller with PCI\n                       interface.')
dot3ChipSetXaQti = MibIdentifier((1, 3, 6, 1, 2, 1, 10, 7, 8, 12))
dot3ChipSetXaQtiXQ11800FP = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 12, 1))
if mibBuilder.loadTexts: dot3ChipSetXaQtiXQ11800FP.setDescription('The authoritative identifier for the XaQTI\n                       XQ11800FP XMAC II Gigabit Ethernet Media Access\n                       Controller.')
dot3ChipSetXaQtiXQ18110FP = ObjectIdentity((1, 3, 6, 1, 2, 1, 10, 7, 8, 12, 2))
if mibBuilder.loadTexts: dot3ChipSetXaQtiXQ18110FP.setDescription('The authoritative identifier for the XaQTI\n                       XQ18110FP GigaPower Protocol Accelerator.')
mibBuilder.exportSymbols("ETHER-CHIPSET-MIB", dot3ChipSetNational83902=dot3ChipSetNational83902, dot3ChipSetJato=dot3ChipSetJato, dot3ChipSetAMD=dot3ChipSetAMD, dot3ChipSetIntel82557=dot3ChipSetIntel82557, dot3ChipSetAMD79C970=dot3ChipSetAMD79C970, dot3ChipSetAMD79C940=dot3ChipSetAMD79C940, dot3ChipSetAMD79C960=dot3ChipSetAMD79C960, dot3ChipSetSeeq8100=dot3ChipSetSeeq8100, dot3ChipSetAMD79900=dot3ChipSetAMD79900, dot3ChipSetIntel=dot3ChipSetIntel, dot3ChipSets=dot3ChipSets, dot3ChipSetSeeq84C30=dot3ChipSetSeeq84C30, dot3ChipSetNational83916=dot3ChipSetNational83916, dot3ChipSetFujitsu86965B=dot3ChipSetFujitsu86965B, dot3ChipSetDigital21140=dot3ChipSetDigital21140, dot3ChipSetSeeq=dot3ChipSetSeeq, dot3ChipSetSeeq80C03=dot3ChipSetSeeq80C03, dot3ChipSetTIX3270=dot3ChipSetTIX3270, dot3ChipSetNational=dot3ChipSetNational, dot3ChipSetNational83905=dot3ChipSetNational83905, dot3ChipSetAMD79C971=dot3ChipSetAMD79C971, dot3ChipSetFujitsu86950=dot3ChipSetFujitsu86950, dot3ChipSetDigital21143=dot3ChipSetDigital21143, dot3ChipSetDigital21041=dot3ChipSetDigital21041, dot3ChipSetSeeq84C300=dot3ChipSetSeeq84C300, dot3ChipSetAMD79C961=dot3ChipSetAMD79C961, dot3ChipSetAMD79C972=dot3ChipSetAMD79C972, dot3ChipSetSeeq80C300=dot3ChipSetSeeq80C300, PYSNMP_MODULE_ID=etherChipsetMIB, dot3ChipSetIntel82595=dot3ChipSetIntel82595, dot3ChipSetTIE110=dot3ChipSetTIE110, dot3ChipSetFujitsu86964=dot3ChipSetFujitsu86964, dot3ChipSetLucentATT1MX10=dot3ChipSetLucentATT1MX10, dot3ChipSetAMD79C965=dot3ChipSetAMD79C965, dot3ChipSetNational83901=dot3ChipSetNational83901, dot3ChipSetFujitsu=dot3ChipSetFujitsu, dot3ChipSetNational83934=dot3ChipSetNational83934, dot3ChipSetIntel82596=dot3ChipSetIntel82596, dot3ChipSetIntel82586=dot3ChipSetIntel82586, dot3ChipSetSeeq84302=dot3ChipSetSeeq84302, dot3ChipSetDigital21340=dot3ChipSetDigital21340, dot3ChipSetDigital21440=dot3ChipSetDigital21440, dot3ChipSetSeeq8003=dot3ChipSetSeeq8003, dot3ChipSetTIE100=dot3ChipSetTIE100, dot3ChipSetLucentLUC3M08=dot3ChipSetLucentLUC3M08, dot3ChipSetSeeq8431=dot3ChipSetSeeq8431, dot3ChipSetGalileoGT48208=dot3ChipSetGalileoGT48208, dot3ChipSetGalileoGT48207=dot3ChipSetGalileoGT48207, dot3ChipSetAMD7990=dot3ChipSetAMD7990, dot3ChipSetDigital21540=dot3ChipSetDigital21540, dot3ChipSetDigitalDC21040=dot3ChipSetDigitalDC21040, dot3ChipSetTI=dot3ChipSetTI, dot3ChipSetToshiba=dot3ChipSetToshiba, dot3ChipSetGalileoGT48004=dot3ChipSetGalileoGT48004, dot3ChipSetTIX3100=dot3ChipSetTIX3100, dot3ChipSetXaQti=dot3ChipSetXaQti, dot3ChipSetToshibaTC35815F=dot3ChipSetToshibaTC35815F, dot3ChipSetFujitsu86960=dot3ChipSetFujitsu86960, dot3ChipSetTIX3150=dot3ChipSetTIX3150, dot3ChipSetLucent=dot3ChipSetLucent, dot3ChipSetAMD79C970A=dot3ChipSetAMD79C970A, dot3ChipSetDigital=dot3ChipSetDigital, dot3ChipSetGalileo=dot3ChipSetGalileo, etherChipsetMIB=etherChipsetMIB, dot3ChipSetGalileoGT48002=dot3ChipSetGalileoGT48002, dot3ChipSetAMD79C90=dot3ChipSetAMD79C90, dot3ChipSetNational8390=dot3ChipSetNational8390, dot3ChipSetGalileoGT48212=dot3ChipSetGalileoGT48212, dot3ChipSetNational83936=dot3ChipSetNational83936, dot3ChipSetGalileoGT48001=dot3ChipSetGalileoGT48001, dot3ChipSetXaQtiXQ18110FP=dot3ChipSetXaQtiXQ18110FP, dot3ChipSetAMD79C961A=dot3ChipSetAMD79C961A, dot3ChipSetSeeq84301=dot3ChipSetSeeq84301, dot3ChipSetXaQtiXQ11800FP=dot3ChipSetXaQtiXQ11800FP, dot3ChipSetFujitsu86965A=dot3ChipSetFujitsu86965A, dot3ChipSetNationalSonic=dot3ChipSetNationalSonic, dot3ChipSetIntel82558=dot3ChipSetIntel82558, dot3ChipSetNational83907=dot3ChipSetNational83907, dot3ChipSetJatoJT1001=dot3ChipSetJatoJT1001)



#
# PySNMP MIB module T11-FC-NAME-SERVER-MIB (http://pysnmp.sf.net)
# ASN.1 source http://mibs.snmplabs.com:80/asn1/T11-FC-NAME-SERVER-MIB
# Produced by pysmi-0.0.7 at Sun Feb 14 00:29:49 2016
# On host bldfarm platform Linux version 4.1.13-100.fc21.x86_64 by user goose
# Using Python version 3.5.0 (default, Jan  5 2016, 17:11:52) 
#
( ObjectIdentifier, Integer, OctetString, ) = mibBuilder.importSymbols("ASN1", "ObjectIdentifier", "Integer", "OctetString")
( NamedValues, ) = mibBuilder.importSymbols("ASN1-ENUMERATION", "NamedValues")
( ConstraintsIntersection, ValueSizeConstraint, ValueRangeConstraint, SingleValueConstraint, ConstraintsUnion, ) = mibBuilder.importSymbols("ASN1-REFINEMENT", "ConstraintsIntersection", "ValueSizeConstraint", "ValueRangeConstraint", "SingleValueConstraint", "ConstraintsUnion")
( fcmInstanceIndex, FcPortType, FcClasses, FcAddressIdOrZero, FcNameIdOrZero, ) = mibBuilder.importSymbols("FC-MGMT-MIB", "fcmInstanceIndex", "FcPortType", "FcClasses", "FcAddressIdOrZero", "FcNameIdOrZero")
( SnmpAdminString, ) = mibBuilder.importSymbols("SNMP-FRAMEWORK-MIB", "SnmpAdminString")
( ModuleCompliance, ObjectGroup, NotificationGroup, ) = mibBuilder.importSymbols("SNMPv2-CONF", "ModuleCompliance", "ObjectGroup", "NotificationGroup")
( MibScalar, MibTable, MibTableRow, MibTableColumn, Counter32, Gauge32, iso, ObjectIdentity, Integer32, Counter64, MibIdentifier, Unsigned32, TimeTicks, mib_2, NotificationType, ModuleIdentity, Bits, IpAddress, ) = mibBuilder.importSymbols("SNMPv2-SMI", "MibScalar", "MibTable", "MibTableRow", "MibTableColumn", "Counter32", "Gauge32", "iso", "ObjectIdentity", "Integer32", "Counter64", "MibIdentifier", "Unsigned32", "TimeTicks", "mib-2", "NotificationType", "ModuleIdentity", "Bits", "IpAddress")
( TextualConvention, DisplayString, TimeStamp, TruthValue, ) = mibBuilder.importSymbols("SNMPv2-TC", "TextualConvention", "DisplayString", "TimeStamp", "TruthValue")
( t11FamLocalSwitchWwn, ) = mibBuilder.importSymbols("T11-FC-FABRIC-ADDR-MGR-MIB", "t11FamLocalSwitchWwn")
( T11FabricIndex, ) = mibBuilder.importSymbols("T11-TC-MIB", "T11FabricIndex")
t11FcNameServerMIB = ModuleIdentity((1, 3, 6, 1, 2, 1, 135)).setRevisions(("2006-03-02 00:00",))
if mibBuilder.loadTexts: t11FcNameServerMIB.setLastUpdated('200603020000Z')
if mibBuilder.loadTexts: t11FcNameServerMIB.setOrganization('T11')
if mibBuilder.loadTexts: t11FcNameServerMIB.setContactInfo('     Claudio DeSanti\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA 95134 USA\n                  Phone: +1 408 853-9172\n                  EMail: cds@cisco.com\n\n                  Keith McCloghrie\n                  Cisco Systems, Inc.\n                  170 West Tasman Drive\n                  San Jose, CA USA 95134\n                  Phone: +1 408-526-5260\n                  EMail: kzm@cisco.com')
if mibBuilder.loadTexts: t11FcNameServerMIB.setDescription('The MIB module for the management of the functionality,\n           which realizes the FC-GS-4 requirements for Name\n           Server (NS).\n\n           Copyright (C) The Internet Society (2006).  This version of\n           this MIB module is part of RFC 4438; see the RFC itself for\n           full legal notices.')
t11NsNotifications = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 0))
t11NsMIBObjects = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 1))
t11NsMIBConformance = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 2))
t11NsStatus = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 1, 1))
t11NsStatistics = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 1, 2))
class T11NsGs4RejectReasonCode(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12,))
    namedValues = NamedValues(("none", 1), ("invalidCmdCode", 2), ("invalidVerLevel", 3), ("logicalError", 4), ("invalidIUSize", 5), ("logicalBusy", 6), ("protocolError", 7), ("unableToPerformCmdReq", 8), ("cmdNotSupported", 9), ("serverNotAvailable", 10), ("couldNotEstabSession", 11), ("vendorError", 12),)

class T11NsRejReasonCodeExpl(Integer32, TextualConvention):
    subtypeSpec = Integer32.subtypeSpec+ConstraintsUnion(SingleValueConstraint(1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24, 25, 26,))
    namedValues = NamedValues(("noAdditionalExplanation", 1), ("portIdentifierNotRegistered", 2), ("portNameNotRegistered", 3), ("nodeNameNotRegistered", 4), ("classOfServiceNotRegistered", 5), ("nodeIpAddressNotRegistered", 6), ("ipaNotRegistered", 7), ("fc4TypeNotRegistered", 8), ("symbolicPortNameNotRegistered", 9), ("symbolicNodeNameNotRegistered", 10), ("portTypeNotRegistered", 11), ("portIpAddressNotRegistered", 12), ("fabricPortNameNotRegistered", 13), ("hardAddressNotRegistered", 14), ("fc4DescriptorNotRegistered", 15), ("fc4FeaturesNotRegistered", 16), ("accessDenied", 17), ("unacceptablePortIdentifier", 18), ("databaseEmpty", 19), ("noObjectRegInSpecifiedScope", 20), ("domainIdNotPresent", 21), ("portIdNotPresent", 22), ("noDeviceAttached", 23), ("authorizationException", 24), ("authenticationException", 25), ("databaseFull", 26),)

t11NsInfoSubsetTable = MibTable((1, 3, 6, 1, 2, 1, 135, 1, 1, 1), )
if mibBuilder.loadTexts: t11NsInfoSubsetTable.setDescription('This table contains one entry for each Name Server\n           Information Subset within each Fibre Channel\n           management instance.')
t11NsInfoSubsetEntry = MibTableRow((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetIndex"))
if mibBuilder.loadTexts: t11NsInfoSubsetEntry.setDescription('This entry contains information about operations\n           on a particular Name Server Information Subset\n           within the Fibre Channel management instance\n           identified by fcmInstanceIndex.')
t11NsInfoSubsetIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(1,4294967295)))
if mibBuilder.loadTexts: t11NsInfoSubsetIndex.setDescription('An arbitrary integer value that uniquely identifies\n           this Name Server Information Subset amongst all others\n           within the same Fibre Channel management instance.\n\n           It is mandatory to keep this value constant between\n           restarts of the agent and to make every possible\n           effort to keep it constant across such restarts.')
t11NsInfoSubsetSwitchIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1, 2), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,4294967295))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInfoSubsetSwitchIndex.setDescription('The value of this object is zero when operations\n           upon this Name Server Information Subset do not occur\n           at a local Fibre Channel switch; otherwise, it is\n           non-zero and identifies the local switch.\n\n           The switch identified by a non-zero value of this\n           object is the same switch as is identified by the\n           same value of fcmSwitchIndex.')
t11NsInfoSubsetTableLastChange = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1, 3), TimeStamp()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInfoSubsetTableLastChange.setDescription('The value of sysUpTime at the time of the last update\n           to any entry in the t11NsRegTable with the same values\n           of fcmInstanceIndex and t11NsInfoSubsetIndex.  This\n           includes creation of an entry, deletion of an entry, or\n           modification of an existing entry.  If no such update\n           has taken place since the last re-initialization of the\n           local network management subsystem, then this object\n           contains a zero value.')
t11NsInfoSubsetNumRows = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1, 4), Integer32().subtype(subtypeSpec=ValueRangeConstraint(0,2147483647))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInfoSubsetNumRows.setDescription('The number of Nx_Ports currently registered in this\n\n\n\n           Name Server Information Subset, i.e., the number of\n           rows in the t11NsRegTable with the same values of\n           fcmInstanceIndex and t11NsInfoSubsetIndex.')
t11NsInfoSubsetTotalRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInfoSubsetTotalRejects.setDescription('The total number of (CT_IU) Requests for Name Server\n           functions that were rejected for inclusion in this\n           Name Server Information Subset, across all Fabrics\n           for which it contains information.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsInfoSubsetRejReqNotfyEnable = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 1, 1, 6), TruthValue().clone('false')).setMaxAccess("readwrite")
if mibBuilder.loadTexts: t11NsInfoSubsetRejReqNotfyEnable.setDescription("This object indicates whether 't11NsRejectRegNotify'\n           notifications are generated by rejections of requests\n           to register information in this Name Server Information\n           Subset.\n\n           If value of this object is 'true', then the\n           notification is generated when a request is rejected.\n           If it is 'false', the notification is not generated.\n\n           The persistence of values of this object across an\n           agent reboot is implementation-dependent.")
t11NsRegTable = MibTable((1, 3, 6, 1, 2, 1, 135, 1, 1, 2), )
if mibBuilder.loadTexts: t11NsRegTable.setDescription('This table contains entries for all Nx_Ports registered\n\n\n\n           in the identified Name Server Information Subsets across\n           all Fabrics for which such subsets contain information.')
t11NsRegEntry = MibTableRow((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegFabricIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegPortIdentifier"))
if mibBuilder.loadTexts: t11NsRegEntry.setDescription('An entry containing information about an Nx_Port\n           represented by t11NsRegPortIdentifier that is registered\n           with a Name Server Information Subset (identified by\n           t11NsInfoSubsetIndex) within the Fibre Channel management\n           instance (identified by fcmInstanceIndex) on the Fabric\n           (identified by t11NsRegFabricIndex).')
t11NsRegFabricIndex = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 1), T11FabricIndex())
if mibBuilder.loadTexts: t11NsRegFabricIndex.setDescription('A unique index value that uniquely identifies a\n           particular Fabric.\n\n           In a Fabric conformant to SW-3, only a single Fabric can\n           operate within a single physical infrastructure, and thus,\n           the value of this Fabric Index will always be 1.\n\n\n\n           However, it is possible that future standards will define\n           how multiple Fabrics, each with its own management\n           instrumentation, could operate within one (or more) physical\n           infrastructures.  To allow for this future possibility, this\n           index value is used to uniquely identify a particular\n           Fabric within a physical infrastructure.')
t11NsRegPortIdentifier = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 2), FcAddressIdOrZero())
if mibBuilder.loadTexts: t11NsRegPortIdentifier.setDescription('The Fibre Channel Address Identifier of this Nx_Port.\n           If no Port Identifier has been registered, then the\n           value of this object is the zero-length string.')
t11NsRegPortName = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 3), FcNameIdOrZero().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegPortName.setDescription('The Port_Name (WWN) of this Nx_Port.\n           If this object has not been registered, then its value\n           is the zero-length string.')
t11NsRegNodeName = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 4), FcNameIdOrZero().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegNodeName.setDescription('The Node_Name (WWN) of this Nx_Port.\n           If this object has not been registered, then its value\n           is the zero-length string.')
t11NsRegClassOfSvc = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 5), FcClasses()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegClassOfSvc.setDescription('The class of service indicator.  This object is an\n           array of bits that contain a bit map of the classes of\n           service supported by the associated port.  If a bit in\n\n\n\n           this object is 1, it indicates that the class of\n           service is supported by the associated port.  When a\n           bit is set to 0, it indicates that no class of service\n           is supported by this Nx_Port.\n\n           If this object has not been not registered for a port,\n           then the instance for that port is not instantiated.')
t11NsRegNodeIpAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 6), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(16,16),)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegNodeIpAddress.setDescription("The IP address of the node of this Nx_Port, in\n           network-byte order, either as a 32-bit IPv4 address or\n           a 128-bit IPv6 address.  For the former, the leftmost 96 bits\n           (12 bytes) should contain x'00 00 00 00 00 00 00 00 00 00 FF\n           FF', and the IPv4 address should be present in the rightmost\n           32 bits.\n\n           Note that the value of this object is the IP address value\n           that is received in the FC-GS-4 message Register IP address\n           (Node) RIP_NN.  It is not validated against any IP address\n           format.\n\n           If no 'IP address (Node)' has been registered, then the\n           value of this object is the zero-length string.")
t11NsRegProcAssoc = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 7), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(8,8),)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegProcAssoc.setDescription("The Fibre Channel Initial Process Associator (IPA).\n\n           If no 'Initial Process Associator' has been registered,\n           then the value of this object is the zero-length string.")
t11NsRegFc4Type = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 8), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(32,32),)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegFc4Type.setDescription("The FC-4 protocol types supported by this Nx_Port.\n           This is an array of 256 bits.  Each bit in the array\n           corresponds to a Type value as defined by Fibre Channel\n           standards and contained in the Type field of the frame\n           header.  The order of the bits in the 256-bit (32-byte)\n           value is the same as defined in FC-GS-4, section 5.2.3.8,\n           and represented in network-byte order.\n\n           If no 'FC-4 TYPEs' has been registered, then the\n           value of this object is the zero-length string.")
t11NsRegPortType = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 9), FcPortType().clone(1)).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegPortType.setDescription("The port type of this port.\n\n           If no 'Port Type' has been registered, then the value\n           of this object is unidentified and is represented by\n           the value 'unknown'.")
t11NsRegPortIpAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 10), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(16,16),)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegPortIpAddress.setDescription("The value that Fibre Channel calls an 'IP Address (Port)'\n           that represents the IP address of the associated port.\n           The value is either in 32-bit IPv4 format or 128-bit IPv6\n           format, in network-byte order.  When this object contains an\n           IPv4 address, the leftmost 96 bits (12 bytes) should contain\n           x'00 00 00 00 00 00 00 00 00 00 FF FF'.  The IPv4 address\n           should be present in the rightmost 32 bits.\n\n           Note that the value of this object is the IP address value\n\n\n\n           that is received in the FC-GS-4 message Register IP address\n           (Port) RIPP_ID.  It is not validated against any IP address\n           format.\n\n           If no 'IP address (Port)' has been registered, then the\n           value of this object is the zero-length string.")
t11NsRegFabricPortName = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 11), FcNameIdOrZero().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegFabricPortName.setDescription("The Fabric Port Name (WWN) of the Fx_Port to which\n           this Nx_Port is attached.\n\n           If no 'Fabric Port Name' has been registered, then the\n           value of this object is the zero-length string.")
t11NsRegHardAddress = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 12), FcAddressIdOrZero().clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegHardAddress.setDescription("The format of this object is identical to the format\n           of Hard Address defined in the Discover Address (ADISC)\n           Extended Link Service (FC-FS).\n\n           Hard Address is the 24-bit NL_Port identifier that\n           consists of:\n             - the 8-bit Domain_ID in the most significant byte\n             - the 8-bit Area_ID in the next most significant\n               byte\n             - the 8-bit AL-PA (Arbitrated Loop Physical Address)\n               which an NL_Port attempts acquire during FC-AL\n               initialization in the least significant byte.\n\n           If the port is not an NL_Port, or if it is an NL_Port\n           but does not have a hard address, then all bits are\n           reported as zeros.\n\n           If no 'Hard Address' has been registered, then the\n\n\n\n           value of this object is the zero-length string.")
t11NsRegSymbolicPortName = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 13), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegSymbolicPortName.setDescription("The user-defined name of this port.\n\n           If no 'Symbolic Port Name' has been registered, then\n           the value of this object is the zero-length string.")
t11NsRegSymbolicNodeName = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 14), SnmpAdminString().subtype(subtypeSpec=ValueSizeConstraint(0,255)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegSymbolicNodeName.setDescription("The user-defined name of the node of this port.\n\n           If no 'Symbolic Node Name' has been registered, then\n           the value of this object is the zero-length string.")
t11NsRegFc4Features = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 2, 1, 15), OctetString().subtype(subtypeSpec=ConstraintsUnion(ValueSizeConstraint(0,0),ValueSizeConstraint(128,128),)).clone(hexValue="")).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegFc4Features.setDescription("The FC-4 Features associated with FC-4 Types on this\n           port encoded as a 128-byte value in network-byte order,\n           or the zero-length string if no 'FC-4 Features' have been\n           registered.\n\n           Section 5.2.3.15 of FC-GS-4 is the authoritative\n           definition of the format of the 128-byte value,\n           i.e., if different, FC-GS-4 takes precedence over the\n           following description:\n\n           The 128-byte value is an array of 4-bit values, one for\n           each FC-4 Type value, positioned as follows: the 5 most\n           significant bits of a Type value identify where it appears\n           within the 128-byte value, specifically, within which word:\n\n\n\n                 - Word 0 (of the 128-byte value) contains information\n                   related to Types '00' through '07';\n                 - Word 1 contains information related to Types\n                   '08' through 0F';\n                 - and so forth, up to Word 31, which contains\n                   information related to Types 'F8' through 'FF'.\n\n           The least significant of the eight 4-bit values in each\n           Word represents an FC-4 Type with 000 as its 3 least\n           significant bits, and most significant 4-bit value in\n           each Word represents an FC-4 Type with 111 as its 3 least\n           significant bits.")
t11NsRegFc4DescriptorTable = MibTable((1, 3, 6, 1, 2, 1, 135, 1, 1, 3), )
if mibBuilder.loadTexts: t11NsRegFc4DescriptorTable.setDescription('This table contains entries for all FC-4 Descriptors\n           registered in the identified Name Server Information\n           Subsets across all Fabrics for which such subsets\n           contain information.')
t11NsRegFc4DescriptorEntry = MibTableRow((1, 3, 6, 1, 2, 1, 135, 1, 1, 3, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegFabricIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegPortIdentifier"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegFc4TypeValue"))
if mibBuilder.loadTexts: t11NsRegFc4DescriptorEntry.setDescription('An entry in the t11NsRegFc4DescriptorTable,\n           containing information about an FC-4 Descriptor\n           that is associated with a particular FC-4 Type\n           value.  The particular FC-4 Descriptor was\n           registered by an Nx_Port (identified by\n           t11NsRegPortIdentifier) in a Name Server Information\n           Subset (identified by t11NsInfoSubsetIndex) within\n           the Fibre Channel management instance (identified by\n           fcmInstanceIndex) on the Fabric (identified by\n\n\n\n           t11NsRegFabricIndex).\n\n           If no FC-4 Descriptors have been registered\n           for a particular port, then there will be no\n           entries in this table for that port.')
t11NsRegFc4TypeValue = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 3, 1, 1), Unsigned32().subtype(subtypeSpec=ValueRangeConstraint(0,255)))
if mibBuilder.loadTexts: t11NsRegFc4TypeValue.setDescription("An integer value that identifies an FC-4 Type value\n           (representing a particular protocol type, as specified\n           in FC-FS) for which an FC-4 Descriptor has been\n           registered.\n\n           An instance of this object contains a 'Type value'\n           that corresponds to a '1' bit in the value of the\n           t11NsRegFc4Type registered for the same port;\n           this correspondence is as specified in FC-GS-4.")
t11NsRegFc4Descriptor = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 3, 1, 2), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRegFc4Descriptor.setDescription('The FC-4 Descriptor value that has been registered\n           for the particular port on the particular Fabric, and\n           for the FC-4 Type represented by the corresponding\n           value of t11NsRegFc4TypeIndex.\n\n           The format of an FC-4 Descriptor is dependent on the\n           corresponding FC-4 Type value, but is represented in\n\n\n\n           network-byte order.')
t11NsStatsTable = MibTable((1, 3, 6, 1, 2, 1, 135, 1, 2, 1), )
if mibBuilder.loadTexts: t11NsStatsTable.setDescription('This table contains per-Fabric state and statistics\n           for operations upon the identified Name Server\n           Information Subsets.')
t11NsStatsEntry = MibTableRow((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegFabricIndex"))
if mibBuilder.loadTexts: t11NsStatsEntry.setDescription('An entry in this table contains state and statistics\n           for operations upon a Name Server Information Subset\n           (identified by t11NsInfoSubsetIndex) within the Fibre\n           Channel management instance (identified by\n           fcmInstanceIndex) on the Fabric (identified by\n           t11NsRegFabricIndex).')
t11NsInGetReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 1), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInGetReqs.setDescription('The total number of (CT_IU) Get Requests\n           received requesting information from this Name\n           Server Information Subset on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsOutGetReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 2), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsOutGetReqs.setDescription('The total number of (CT_IU) Get Requests sent in\n           order to obtain information needed in this Name Server\n           Information Subset on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsInRegReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 3), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInRegReqs.setDescription('The total number of (CT_IU) Registration Requests\n           received to register information in the Name Server\n           Information Subset on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsInDeRegReqs = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 4), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInDeRegReqs.setDescription('The total number of (CT_IU) De-registration Requests\n           received to de-register information from this Name Server\n           Information Subset on this Fabric.\n\n           This counter has no discontinuities other than those\n\n\n\n           that all Counter32s have when sysUpTime=0.')
t11NsInRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 5), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsInRscns.setDescription('The total number of received RSCNs, indicating\n           Name Server-related changes relating to this Name\n           Server Information Subset on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsOutRscns = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 6), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsOutRscns.setDescription('The total number of transmitted RSCNs, indicating\n           Name Server-related changes relating to this Name\n           Server Information Subset on this Fabric.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsRejects = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 7), Counter32()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRejects.setDescription('The total number of CT_IU Requests for Name\n           Server functions on this Name Server Information\n           Subset on this Fabric that were rejected.\n\n           This counter has no discontinuities other than those\n           that all Counter32s have when sysUpTime=0.')
t11NsDatabaseFull = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 2, 1, 1, 8), TruthValue()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsDatabaseFull.setDescription("An indication of whether the database containing this\n\n\n\n           Name Server Information Subset is full.  This object is\n           set to 'true' only if the Name Server is unable to allocate\n           space for a new entry for the corresponding Fabric, and it is\n           set to 'false' whenever an existing entry is deleted for the\n           corresponding Fabric.")
t11NsRejectTable = MibTable((1, 3, 6, 1, 2, 1, 135, 1, 1, 4), )
if mibBuilder.loadTexts: t11NsRejectTable.setDescription('This table contains information about the most recent\n           Name Server Registration Request failures for various\n           ports on various Fabrics.\n\n           If no information is available about the most recent\n           rejection of a Registration Request on a particular port\n           on a particular Fabric, then there will no entry in this\n           table for that port and Fabric.\n\n           When a t11NsRejectRegNotify notification is sent for\n           such a Registration Request failure, the values of the\n           objects in the relevant entry of this table are updated\n           immediately prior to generating the notification.')
t11NsRejectEntry = MibTableRow((1, 3, 6, 1, 2, 1, 135, 1, 1, 4, 1), ).setIndexNames((0, "FC-MGMT-MIB", "fcmInstanceIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegFabricIndex"), (0, "T11-FC-NAME-SERVER-MIB", "t11NsRegPortIdentifier"))
if mibBuilder.loadTexts: t11NsRejectEntry.setDescription('An entry containing information about the most recent\n           rejection of a request to register information in the Name\n           Server Information Subset (identified by\n           t11NsInfoSubsetIndex) within the Fibre Channel management\n           instance (identified by fcmInstanceIndex) for a particular\n           port (identified by t11NsRegPortIdentifier) on a particular\n           Fabric (identified by t11NsRegFabricIndex).')
t11NsRejectCtCommandString = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 4, 1, 1), OctetString().subtype(subtypeSpec=ValueSizeConstraint(0,255))).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRejectCtCommandString.setDescription("The binary content of the Registration Request,\n           formatted as an octet string (in network byte\n           order) containing the CT_IU, as described in\n           Table 2 of [FC-GS-4] (including the preamble),\n           which was most recently rejected for the particular\n           Name Server Information Subset on the particular port\n           on the particular Fabric.\n\n           This object contains the zero-length string\n           if and when the CT-IU's content is unavailable.\n\n           When the length of this object is 255 octets, it\n           contains the first 255 octets of the CT-IU (in\n           network-byte order).")
t11NsRejectReasonCode = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 4, 1, 2), T11NsGs4RejectReasonCode()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRejectReasonCode.setDescription('A registration reject reason code.  This object\n           contains the reason code of the most recent Name\n           Server Registration Request failure for the\n           particular port on the particular Fabric.')
t11NsRejReasonCodeExp = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 4, 1, 3), T11NsRejReasonCodeExpl()).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRejReasonCodeExp.setDescription('A registration reject reason code explanation.  This\n           object contains the reason code explanation of the most\n           recent Name Server Registration Request failure for the\n           particular port on the particular Fabric.')
t11NsRejReasonVendorCode = MibTableColumn((1, 3, 6, 1, 2, 1, 135, 1, 1, 4, 1, 4), OctetString().subtype(subtypeSpec=ValueSizeConstraint(1,1)).setFixedLength(1)).setMaxAccess("readonly")
if mibBuilder.loadTexts: t11NsRejReasonVendorCode.setDescription('A registration reject vendor-specific code.  This\n           object contains the vendor-specific code of the most\n           recent Name Server Registration Request failure for the\n           particular port on the particular Fabric.')
t11NsRejectRegNotify = NotificationType((1, 3, 6, 1, 2, 1, 135, 0, 1)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11FamLocalSwitchWwn"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegPortName"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejectCtCommandString"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejectReasonCode"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejReasonCodeExp"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejReasonVendorCode"),))
if mibBuilder.loadTexts: t11NsRejectRegNotify.setDescription("This notification is generated whenever a request to\n           register information in a Name Server Information\n           Subset (for which the corresponding instance of\n           t11NsInfoSubsetRejReqNotfyEnable is 'true') is\n           rejected on a particular Fabric for a particular Nx_Port.\n\n           The value of t11FamLocalSwitchWwn indicates the\n           WWN of the switch that received the request.\n           (If the WWN is unavailable, the value is set to\n           the zero-length string.)\n\n           The value of t11NsRejectCtCommandString indicates\n           the rejected request, and the values of\n           t11NsRejectReasonCode, t11NsRejReasonCodeExp, and\n           t11NsRejReasonVendorCode indicate the reason for\n           the rejection.\n\n           The value of t11NsRegPortName represents the Port Name\n           if it is able to be extracted out of the Registration\n           Request, or otherwise the value as currently registered\n           on the port.")
t11NsMIBCompliances = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 2, 1))
t11NsMIBGroups = MibIdentifier((1, 3, 6, 1, 2, 1, 135, 2, 2))
t11NsMIBCompliance = ModuleCompliance((1, 3, 6, 1, 2, 1, 135, 2, 1, 1)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsDBGroup"), ("T11-FC-NAME-SERVER-MIB", "t11NsNotifyControlGroup"), ("T11-FC-NAME-SERVER-MIB", "t11NsNotifyGroup"),))
if mibBuilder.loadTexts: t11NsMIBCompliance.setDescription('The compliance statement for entities that\n           implement the Fibre Channel Name Server.')
t11NsDBGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 135, 2, 2, 1)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetSwitchIndex"), ("T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetTableLastChange"), ("T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetNumRows"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegPortName"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegNodeName"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegClassOfSvc"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegNodeIpAddress"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegProcAssoc"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegFc4Type"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegPortType"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegPortIpAddress"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegFabricPortName"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegHardAddress"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegSymbolicPortName"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegSymbolicNodeName"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegFc4Features"), ("T11-FC-NAME-SERVER-MIB", "t11NsRegFc4Descriptor"),))
if mibBuilder.loadTexts: t11NsDBGroup.setDescription('A collection of objects for monitoring the information\n           registered in a Name Server Information Subset.')
t11NsRequestStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 135, 2, 2, 2)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsInGetReqs"), ("T11-FC-NAME-SERVER-MIB", "t11NsOutGetReqs"), ("T11-FC-NAME-SERVER-MIB", "t11NsInRegReqs"), ("T11-FC-NAME-SERVER-MIB", "t11NsInDeRegReqs"), ("T11-FC-NAME-SERVER-MIB", "t11NsDatabaseFull"),))
if mibBuilder.loadTexts: t11NsRequestStatsGroup.setDescription('A collection of objects for displaying Name\n           Server statistics and state for Name Server requests.')
t11NsRscnStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 135, 2, 2, 3)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsInRscns"), ("T11-FC-NAME-SERVER-MIB", "t11NsOutRscns"),))
if mibBuilder.loadTexts: t11NsRscnStatsGroup.setDescription('A collection of objects for displaying Name\n           Server statistics for Name Server-related RSCNs.')
t11NsRejectStatsGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 135, 2, 2, 4)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetTotalRejects"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejects"),))
if mibBuilder.loadTexts: t11NsRejectStatsGroup.setDescription('A collection of objects for displaying Name\n           Server statistics for rejects.')
t11NsNotifyControlGroup = ObjectGroup((1, 3, 6, 1, 2, 1, 135, 2, 2, 5)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsRejectCtCommandString"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejectReasonCode"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejReasonCodeExp"), ("T11-FC-NAME-SERVER-MIB", "t11NsRejReasonVendorCode"), ("T11-FC-NAME-SERVER-MIB", "t11NsInfoSubsetRejReqNotfyEnable"),))
if mibBuilder.loadTexts: t11NsNotifyControlGroup.setDescription('A collection of notification control and\n           notification information objects for monitoring\n           rejections of Name Server registrations.')
t11NsNotifyGroup = NotificationGroup((1, 3, 6, 1, 2, 1, 135, 2, 2, 6)).setObjects(*(("T11-FC-NAME-SERVER-MIB", "t11NsRejectRegNotify"),))
if mibBuilder.loadTexts: t11NsNotifyGroup.setDescription('A collection of notifications for monitoring\n           rejections of Name Server registrations.')
mibBuilder.exportSymbols("T11-FC-NAME-SERVER-MIB", t11NsRegNodeName=t11NsRegNodeName, t11NsDBGroup=t11NsDBGroup, t11NsNotifications=t11NsNotifications, t11NsRegClassOfSvc=t11NsRegClassOfSvc, t11NsRejectCtCommandString=t11NsRejectCtCommandString, t11NsRegFc4Type=t11NsRegFc4Type, t11NsStatsTable=t11NsStatsTable, t11NsNotifyGroup=t11NsNotifyGroup, t11NsInDeRegReqs=t11NsInDeRegReqs, t11NsRequestStatsGroup=t11NsRequestStatsGroup, t11NsRegPortIpAddress=t11NsRegPortIpAddress, t11FcNameServerMIB=t11FcNameServerMIB, t11NsOutGetReqs=t11NsOutGetReqs, t11NsRejReasonVendorCode=t11NsRejReasonVendorCode, t11NsMIBGroups=t11NsMIBGroups, t11NsRejects=t11NsRejects, t11NsRegNodeIpAddress=t11NsRegNodeIpAddress, t11NsInGetReqs=t11NsInGetReqs, t11NsStatsEntry=t11NsStatsEntry, t11NsInfoSubsetRejReqNotfyEnable=t11NsInfoSubsetRejReqNotfyEnable, t11NsRegFabricIndex=t11NsRegFabricIndex, t11NsStatistics=t11NsStatistics, t11NsInfoSubsetIndex=t11NsInfoSubsetIndex, t11NsRejectTable=t11NsRejectTable, t11NsInRegReqs=t11NsInRegReqs, t11NsRejectRegNotify=t11NsRejectRegNotify, t11NsMIBCompliance=t11NsMIBCompliance, t11NsRegPortType=t11NsRegPortType, t11NsRegPortIdentifier=t11NsRegPortIdentifier, t11NsRegSymbolicPortName=t11NsRegSymbolicPortName, T11NsRejReasonCodeExpl=T11NsRejReasonCodeExpl, t11NsInfoSubsetEntry=t11NsInfoSubsetEntry, t11NsRejReasonCodeExp=t11NsRejReasonCodeExp, t11NsInfoSubsetSwitchIndex=t11NsInfoSubsetSwitchIndex, t11NsRejectStatsGroup=t11NsRejectStatsGroup, t11NsInfoSubsetNumRows=t11NsInfoSubsetNumRows, t11NsRegFc4TypeValue=t11NsRegFc4TypeValue, t11NsRscnStatsGroup=t11NsRscnStatsGroup, t11NsRegFc4DescriptorTable=t11NsRegFc4DescriptorTable, t11NsRegTable=t11NsRegTable, t11NsRejectReasonCode=t11NsRejectReasonCode, T11NsGs4RejectReasonCode=T11NsGs4RejectReasonCode, t11NsRegPortName=t11NsRegPortName, t11NsRegFc4DescriptorEntry=t11NsRegFc4DescriptorEntry, t11NsRegSymbolicNodeName=t11NsRegSymbolicNodeName, t11NsRegEntry=t11NsRegEntry, t11NsOutRscns=t11NsOutRscns, t11NsRegFc4Descriptor=t11NsRegFc4Descriptor, t11NsRejectEntry=t11NsRejectEntry, t11NsMIBCompliances=t11NsMIBCompliances, t11NsInfoSubsetTable=t11NsInfoSubsetTable, t11NsRegProcAssoc=t11NsRegProcAssoc, t11NsRegFc4Features=t11NsRegFc4Features, t11NsMIBObjects=t11NsMIBObjects, t11NsDatabaseFull=t11NsDatabaseFull, t11NsRegFabricPortName=t11NsRegFabricPortName, t11NsMIBConformance=t11NsMIBConformance, t11NsInfoSubsetTableLastChange=t11NsInfoSubsetTableLastChange, PYSNMP_MODULE_ID=t11FcNameServerMIB, t11NsStatus=t11NsStatus, t11NsRegHardAddress=t11NsRegHardAddress, t11NsInRscns=t11NsInRscns, t11NsNotifyControlGroup=t11NsNotifyControlGroup, t11NsInfoSubsetTotalRejects=t11NsInfoSubsetTotalRejects)
